Class: HatchetSdkRest::DefaultApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::DefaultApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#info_get_version(opts = {}) ⇒ InfoGetVersion200Response
We return the version for the currently running server Get the version of the server.
-
#info_get_version_with_http_info(opts = {}) ⇒ Array<(InfoGetVersion200Response, Integer, Hash)>
We return the version for the currently running server Get the version of the server.
-
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
constructor
A new instance of DefaultApi.
-
#monitoring_post_run_probe(tenant, opts = {}) ⇒ nil
Detailed Health Probe For the Instance Triggers a workflow to check the status of the instance.
-
#monitoring_post_run_probe_with_http_info(tenant, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Detailed Health Probe For the Instance Triggers a workflow to check the status of the instance.
-
#tenant_invite_delete(tenant, tenant_invite, opts = {}) ⇒ TenantInvite
Delete invite Deletes a tenant invite.
-
#tenant_invite_delete_with_http_info(tenant, tenant_invite, opts = {}) ⇒ Array<(TenantInvite, Integer, Hash)>
Delete invite Deletes a tenant invite.
-
#tenant_invite_update(tenant, tenant_invite, update_tenant_invite_request, opts = {}) ⇒ TenantInvite
Update invite Updates a tenant invite.
-
#tenant_invite_update_with_http_info(tenant, tenant_invite, update_tenant_invite_request, opts = {}) ⇒ Array<(TenantInvite, Integer, Hash)>
Update invite Updates a tenant invite.
-
#webhook_create(tenant, opts = {}) ⇒ WebhookWorkerCreated
Create a webhook Creates a webhook.
-
#webhook_create_with_http_info(tenant, opts = {}) ⇒ Array<(WebhookWorkerCreated, Integer, Hash)>
Create a webhook Creates a webhook.
-
#webhook_delete(webhook, opts = {}) ⇒ nil
Delete a webhook Deletes a webhook.
-
#webhook_delete_with_http_info(webhook, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a webhook Deletes a webhook.
-
#webhook_list(tenant, opts = {}) ⇒ WebhookWorkerListResponse
List webhooks Lists all webhooks.
-
#webhook_list_with_http_info(tenant, opts = {}) ⇒ Array<(WebhookWorkerListResponse, Integer, Hash)>
List webhooks Lists all webhooks.
-
#webhook_requests_list(webhook, opts = {}) ⇒ WebhookWorkerRequestListResponse
List webhook requests Lists all requests for a webhook.
-
#webhook_requests_list_with_http_info(webhook, opts = {}) ⇒ Array<(WebhookWorkerRequestListResponse, Integer, Hash)>
List webhook requests Lists all requests for a webhook.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
Returns a new instance of DefaultApi.
19 20 21 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#info_get_version(opts = {}) ⇒ InfoGetVersion200Response
We return the version for the currently running server Get the version of the server
26 27 28 29 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 26 def info_get_version(opts = {}) data, _status_code, _headers = info_get_version_with_http_info(opts) data end |
#info_get_version_with_http_info(opts = {}) ⇒ Array<(InfoGetVersion200Response, Integer, Hash)>
We return the version for the currently running server Get the version of the server
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 35 def info_get_version_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.info_get_version ...' end # resource path local_var_path = '/api/v1/version' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InfoGetVersion200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"DefaultApi.info_get_version", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#info_get_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#monitoring_post_run_probe(tenant, opts = {}) ⇒ nil
Detailed Health Probe For the Instance Triggers a workflow to check the status of the instance
84 85 86 87 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 84 def monitoring_post_run_probe(tenant, opts = {}) monitoring_post_run_probe_with_http_info(tenant, opts) nil end |
#monitoring_post_run_probe_with_http_info(tenant, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Detailed Health Probe For the Instance Triggers a workflow to check the status of the instance
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 94 def monitoring_post_run_probe_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.monitoring_post_run_probe ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling DefaultApi.monitoring_post_run_probe" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.monitoring_post_run_probe, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.monitoring_post_run_probe, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/monitoring/{tenant}/probe'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"DefaultApi.monitoring_post_run_probe", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#monitoring_post_run_probe\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#tenant_invite_delete(tenant, tenant_invite, opts = {}) ⇒ TenantInvite
Delete invite Deletes a tenant invite
156 157 158 159 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 156 def tenant_invite_delete(tenant, tenant_invite, opts = {}) data, _status_code, _headers = tenant_invite_delete_with_http_info(tenant, tenant_invite, opts) data end |
#tenant_invite_delete_with_http_info(tenant, tenant_invite, opts = {}) ⇒ Array<(TenantInvite, Integer, Hash)>
Delete invite Deletes a tenant invite
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 167 def tenant_invite_delete_with_http_info(tenant, tenant_invite, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.tenant_invite_delete ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling DefaultApi.tenant_invite_delete" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.tenant_invite_delete, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.tenant_invite_delete, the character length must be greater than or equal to 36.' end # verify the required parameter 'tenant_invite' is set if @api_client.config.client_side_validation && tenant_invite.nil? fail ArgumentError, "Missing the required parameter 'tenant_invite' when calling DefaultApi.tenant_invite_delete" end if @api_client.config.client_side_validation && tenant_invite.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant_invite" when calling DefaultApi.tenant_invite_delete, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant_invite.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant_invite" when calling DefaultApi.tenant_invite_delete, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/invites/{tenant-invite}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'tenant-invite' + '}', CGI.escape(tenant_invite.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TenantInvite' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"DefaultApi.tenant_invite_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#tenant_invite_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#tenant_invite_update(tenant, tenant_invite, update_tenant_invite_request, opts = {}) ⇒ TenantInvite
Update invite Updates a tenant invite
242 243 244 245 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 242 def tenant_invite_update(tenant, tenant_invite, update_tenant_invite_request, opts = {}) data, _status_code, _headers = tenant_invite_update_with_http_info(tenant, tenant_invite, update_tenant_invite_request, opts) data end |
#tenant_invite_update_with_http_info(tenant, tenant_invite, update_tenant_invite_request, opts = {}) ⇒ Array<(TenantInvite, Integer, Hash)>
Update invite Updates a tenant invite
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 254 def tenant_invite_update_with_http_info(tenant, tenant_invite, update_tenant_invite_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.tenant_invite_update ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling DefaultApi.tenant_invite_update" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.tenant_invite_update, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.tenant_invite_update, the character length must be greater than or equal to 36.' end # verify the required parameter 'tenant_invite' is set if @api_client.config.client_side_validation && tenant_invite.nil? fail ArgumentError, "Missing the required parameter 'tenant_invite' when calling DefaultApi.tenant_invite_update" end if @api_client.config.client_side_validation && tenant_invite.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant_invite" when calling DefaultApi.tenant_invite_update, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant_invite.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant_invite" when calling DefaultApi.tenant_invite_update, the character length must be greater than or equal to 36.' end # verify the required parameter 'update_tenant_invite_request' is set if @api_client.config.client_side_validation && update_tenant_invite_request.nil? fail ArgumentError, "Missing the required parameter 'update_tenant_invite_request' when calling DefaultApi.tenant_invite_update" end # resource path local_var_path = '/api/v1/tenants/{tenant}/invites/{tenant-invite}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'tenant-invite' + '}', CGI.escape(tenant_invite.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_tenant_invite_request) # return_type return_type = opts[:debug_return_type] || 'TenantInvite' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"DefaultApi.tenant_invite_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#tenant_invite_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#webhook_create(tenant, opts = {}) ⇒ WebhookWorkerCreated
Create a webhook Creates a webhook
337 338 339 340 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 337 def webhook_create(tenant, opts = {}) data, _status_code, _headers = webhook_create_with_http_info(tenant, opts) data end |
#webhook_create_with_http_info(tenant, opts = {}) ⇒ Array<(WebhookWorkerCreated, Integer, Hash)>
Create a webhook Creates a webhook
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 348 def webhook_create_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.webhook_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling DefaultApi.webhook_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.webhook_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.webhook_create, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/webhook-workers'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_worker_create_request']) # return_type return_type = opts[:debug_return_type] || 'WebhookWorkerCreated' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"DefaultApi.webhook_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#webhook_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#webhook_delete(webhook, opts = {}) ⇒ nil
Delete a webhook Deletes a webhook
414 415 416 417 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 414 def webhook_delete(webhook, opts = {}) webhook_delete_with_http_info(webhook, opts) nil end |
#webhook_delete_with_http_info(webhook, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a webhook Deletes a webhook
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 424 def webhook_delete_with_http_info(webhook, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.webhook_delete ...' end # verify the required parameter 'webhook' is set if @api_client.config.client_side_validation && webhook.nil? fail ArgumentError, "Missing the required parameter 'webhook' when calling DefaultApi.webhook_delete" end if @api_client.config.client_side_validation && webhook.to_s.length > 36 fail ArgumentError, 'invalid value for "webhook" when calling DefaultApi.webhook_delete, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && webhook.to_s.length < 36 fail ArgumentError, 'invalid value for "webhook" when calling DefaultApi.webhook_delete, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/webhook-workers/{webhook}'.sub('{' + 'webhook' + '}', CGI.escape(webhook.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"DefaultApi.webhook_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#webhook_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#webhook_list(tenant, opts = {}) ⇒ WebhookWorkerListResponse
List webhooks Lists all webhooks
485 486 487 488 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 485 def webhook_list(tenant, opts = {}) data, _status_code, _headers = webhook_list_with_http_info(tenant, opts) data end |
#webhook_list_with_http_info(tenant, opts = {}) ⇒ Array<(WebhookWorkerListResponse, Integer, Hash)>
List webhooks Lists all webhooks
495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 495 def webhook_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.webhook_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling DefaultApi.webhook_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.webhook_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling DefaultApi.webhook_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/webhook-workers'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookWorkerListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"DefaultApi.webhook_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#webhook_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#webhook_requests_list(webhook, opts = {}) ⇒ WebhookWorkerRequestListResponse
List webhook requests Lists all requests for a webhook
556 557 558 559 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 556 def webhook_requests_list(webhook, opts = {}) data, _status_code, _headers = webhook_requests_list_with_http_info(webhook, opts) data end |
#webhook_requests_list_with_http_info(webhook, opts = {}) ⇒ Array<(WebhookWorkerRequestListResponse, Integer, Hash)>
List webhook requests Lists all requests for a webhook
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/default_api.rb', line 566 def webhook_requests_list_with_http_info(webhook, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.webhook_requests_list ...' end # verify the required parameter 'webhook' is set if @api_client.config.client_side_validation && webhook.nil? fail ArgumentError, "Missing the required parameter 'webhook' when calling DefaultApi.webhook_requests_list" end if @api_client.config.client_side_validation && webhook.to_s.length > 36 fail ArgumentError, 'invalid value for "webhook" when calling DefaultApi.webhook_requests_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && webhook.to_s.length < 36 fail ArgumentError, 'invalid value for "webhook" when calling DefaultApi.webhook_requests_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/webhook-workers/{webhook}/requests'.sub('{' + 'webhook' + '}', CGI.escape(webhook.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookWorkerRequestListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"DefaultApi.webhook_requests_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#webhook_requests_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |