Class: HatchetSdkRest::EventApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::EventApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#event_create(tenant, create_event_request, opts = {}) ⇒ Event
Create event Creates a new event.
-
#event_create_bulk(tenant, bulk_create_event_request, opts = {}) ⇒ Events
Bulk Create events Bulk creates new events.
-
#event_create_bulk_with_http_info(tenant, bulk_create_event_request, opts = {}) ⇒ Array<(Events, Integer, Hash)>
Bulk Create events Bulk creates new events.
-
#event_create_with_http_info(tenant, create_event_request, opts = {}) ⇒ Array<(Event, Integer, Hash)>
Create event Creates a new event.
-
#event_data_get(event, opts = {}) ⇒ EventData
Get event data Get the data for an event.
-
#event_data_get_with_http_info(event, opts = {}) ⇒ Array<(EventData, Integer, Hash)>
Get event data Get the data for an event.
-
#event_data_get_with_tenant(event_with_tenant, tenant, opts = {}) ⇒ EventData
Get event data Get the data for an event.
-
#event_data_get_with_tenant_with_http_info(event_with_tenant, tenant, opts = {}) ⇒ Array<(EventData, Integer, Hash)>
Get event data Get the data for an event.
-
#event_get(event, opts = {}) ⇒ Event
Get event data Get an event.
-
#event_get_with_http_info(event, opts = {}) ⇒ Array<(Event, Integer, Hash)>
Get event data Get an event.
-
#event_key_list(tenant, opts = {}) ⇒ EventKeyList
List event keys Lists all event keys for a tenant.
-
#event_key_list_with_http_info(tenant, opts = {}) ⇒ Array<(EventKeyList, Integer, Hash)>
List event keys Lists all event keys for a tenant.
-
#event_list(tenant, opts = {}) ⇒ EventList
List events Lists all events for a tenant.
-
#event_list_with_http_info(tenant, opts = {}) ⇒ Array<(EventList, Integer, Hash)>
List events Lists all events for a tenant.
-
#event_update_cancel(tenant, cancel_event_request, opts = {}) ⇒ EventUpdateCancel200Response
Replay events Cancels all runs for a list of events.
-
#event_update_cancel_with_http_info(tenant, cancel_event_request, opts = {}) ⇒ Array<(EventUpdateCancel200Response, Integer, Hash)>
Replay events Cancels all runs for a list of events.
-
#event_update_replay(tenant, replay_event_request, opts = {}) ⇒ EventList
Replay events Replays a list of events.
-
#event_update_replay_with_http_info(tenant, replay_event_request, opts = {}) ⇒ Array<(EventList, Integer, Hash)>
Replay events Replays a list of events.
-
#initialize(api_client = ApiClient.default) ⇒ EventApi
constructor
A new instance of EventApi.
-
#v1_event_get(tenant, v1_event, opts = {}) ⇒ V1Event
Get events Get an event by its id.
-
#v1_event_get_with_http_info(tenant, v1_event, opts = {}) ⇒ Array<(V1Event, Integer, Hash)>
Get events Get an event by its id.
-
#v1_event_key_list(tenant, opts = {}) ⇒ EventKeyList
List event keys Lists all event keys for a tenant.
-
#v1_event_key_list_with_http_info(tenant, opts = {}) ⇒ Array<(EventKeyList, Integer, Hash)>
List event keys Lists all event keys for a tenant.
-
#v1_event_list(tenant, opts = {}) ⇒ V1EventList
List events Lists all events for a tenant.
-
#v1_event_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1EventList, Integer, Hash)>
List events Lists all events for a tenant.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#event_create(tenant, create_event_request, opts = {}) ⇒ Event
Create event Creates a new event.
28 29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 28 def event_create(tenant, create_event_request, opts = {}) data, _status_code, _headers = event_create_with_http_info(tenant, create_event_request, opts) data end |
#event_create_bulk(tenant, bulk_create_event_request, opts = {}) ⇒ Events
Bulk Create events Bulk creates new events.
110 111 112 113 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 110 def event_create_bulk(tenant, bulk_create_event_request, opts = {}) data, _status_code, _headers = event_create_bulk_with_http_info(tenant, bulk_create_event_request, opts) data end |
#event_create_bulk_with_http_info(tenant, bulk_create_event_request, opts = {}) ⇒ Array<(Events, Integer, Hash)>
Bulk Create events Bulk creates new events.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 121 def event_create_bulk_with_http_info(tenant, bulk_create_event_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_create_bulk ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.event_create_bulk" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_create_bulk, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_create_bulk, the character length must be greater than or equal to 36.' end # verify the required parameter 'bulk_create_event_request' is set if @api_client.config.client_side_validation && bulk_create_event_request.nil? fail ArgumentError, "Missing the required parameter 'bulk_create_event_request' when calling EventApi.event_create_bulk" end # resource path local_var_path = '/api/v1/tenants/{tenant}/events/bulk'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(bulk_create_event_request) # return_type return_type = opts[:debug_return_type] || 'Events' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_create_bulk", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_create_bulk\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_create_with_http_info(tenant, create_event_request, opts = {}) ⇒ Array<(Event, Integer, Hash)>
Create event Creates a new event.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 39 def event_create_with_http_info(tenant, create_event_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.event_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_create, the character length must be greater than or equal to 36.' end # verify the required parameter 'create_event_request' is set if @api_client.config.client_side_validation && create_event_request.nil? fail ArgumentError, "Missing the required parameter 'create_event_request' when calling EventApi.event_create" end # resource path local_var_path = '/api/v1/tenants/{tenant}/events'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_event_request) # return_type return_type = opts[:debug_return_type] || 'Event' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_data_get(event, opts = {}) ⇒ EventData
Get event data Get the data for an event.
191 192 193 194 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 191 def event_data_get(event, opts = {}) data, _status_code, _headers = event_data_get_with_http_info(event, opts) data end |
#event_data_get_with_http_info(event, opts = {}) ⇒ Array<(EventData, Integer, Hash)>
Get event data Get the data for an event.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 201 def event_data_get_with_http_info(event, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_data_get ...' end # verify the required parameter 'event' is set if @api_client.config.client_side_validation && event.nil? fail ArgumentError, "Missing the required parameter 'event' when calling EventApi.event_data_get" end if @api_client.config.client_side_validation && event.to_s.length > 36 fail ArgumentError, 'invalid value for "event" when calling EventApi.event_data_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && event.to_s.length < 36 fail ArgumentError, 'invalid value for "event" when calling EventApi.event_data_get, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/events/{event}/data'.sub('{' + 'event' + '}', CGI.escape(event.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventData' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_data_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_data_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_data_get_with_tenant(event_with_tenant, tenant, opts = {}) ⇒ EventData
Get event data Get the data for an event.
263 264 265 266 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 263 def event_data_get_with_tenant(event_with_tenant, tenant, opts = {}) data, _status_code, _headers = event_data_get_with_tenant_with_http_info(event_with_tenant, tenant, opts) data end |
#event_data_get_with_tenant_with_http_info(event_with_tenant, tenant, opts = {}) ⇒ Array<(EventData, Integer, Hash)>
Get event data Get the data for an event.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 274 def event_data_get_with_tenant_with_http_info(event_with_tenant, tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_data_get_with_tenant ...' end # verify the required parameter 'event_with_tenant' is set if @api_client.config.client_side_validation && event_with_tenant.nil? fail ArgumentError, "Missing the required parameter 'event_with_tenant' when calling EventApi.event_data_get_with_tenant" end if @api_client.config.client_side_validation && event_with_tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "event_with_tenant" when calling EventApi.event_data_get_with_tenant, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && event_with_tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "event_with_tenant" when calling EventApi.event_data_get_with_tenant, the character length must be greater than or equal to 36.' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.event_data_get_with_tenant" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_data_get_with_tenant, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_data_get_with_tenant, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/events/{event-with-tenant}/data'.sub('{' + 'event-with-tenant' + '}', CGI.escape(event_with_tenant.to_s)).sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventData' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_data_get_with_tenant", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_data_get_with_tenant\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_get(event, opts = {}) ⇒ Event
Get event data Get an event.
347 348 349 350 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 347 def event_get(event, opts = {}) data, _status_code, _headers = event_get_with_http_info(event, opts) data end |
#event_get_with_http_info(event, opts = {}) ⇒ Array<(Event, Integer, Hash)>
Get event data Get an event.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 357 def event_get_with_http_info(event, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_get ...' end # verify the required parameter 'event' is set if @api_client.config.client_side_validation && event.nil? fail ArgumentError, "Missing the required parameter 'event' when calling EventApi.event_get" end if @api_client.config.client_side_validation && event.to_s.length > 36 fail ArgumentError, 'invalid value for "event" when calling EventApi.event_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && event.to_s.length < 36 fail ArgumentError, 'invalid value for "event" when calling EventApi.event_get, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/events/{event}'.sub('{' + 'event' + '}', CGI.escape(event.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Event' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_key_list(tenant, opts = {}) ⇒ EventKeyList
List event keys Lists all event keys for a tenant.
418 419 420 421 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 418 def event_key_list(tenant, opts = {}) data, _status_code, _headers = event_key_list_with_http_info(tenant, opts) data end |
#event_key_list_with_http_info(tenant, opts = {}) ⇒ Array<(EventKeyList, Integer, Hash)>
List event keys Lists all event keys for a tenant.
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 428 def event_key_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_key_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.event_key_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_key_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_key_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/events/keys'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventKeyList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_key_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_key_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_list(tenant, opts = {}) ⇒ EventList
List events Lists all events for a tenant.
499 500 501 502 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 499 def event_list(tenant, opts = {}) data, _status_code, _headers = event_list_with_http_info(tenant, opts) data end |
#event_list_with_http_info(tenant, opts = {}) ⇒ Array<(EventList, Integer, Hash)>
List events Lists all events for a tenant.
519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 519 def event_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.event_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/events'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'keys'] = @api_client.build_collection_param(opts[:'keys'], :multi) if !opts[:'keys'].nil? query_params[:'workflows'] = @api_client.build_collection_param(opts[:'workflows'], :multi) if !opts[:'workflows'].nil? query_params[:'statuses'] = @api_client.build_collection_param(opts[:'statuses'], :multi) if !opts[:'statuses'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'orderByField'] = opts[:'order_by_field'] if !opts[:'order_by_field'].nil? query_params[:'orderByDirection'] = opts[:'order_by_direction'] if !opts[:'order_by_direction'].nil? query_params[:'additionalMetadata'] = @api_client.build_collection_param(opts[:'additional_metadata'], :multi) if !opts[:'additional_metadata'].nil? query_params[:'eventIds'] = @api_client.build_collection_param(opts[:'event_ids'], :multi) if !opts[:'event_ids'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_update_cancel(tenant, cancel_event_request, opts = {}) ⇒ EventUpdateCancel200Response
Replay events Cancels all runs for a list of events.
591 592 593 594 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 591 def event_update_cancel(tenant, cancel_event_request, opts = {}) data, _status_code, _headers = event_update_cancel_with_http_info(tenant, cancel_event_request, opts) data end |
#event_update_cancel_with_http_info(tenant, cancel_event_request, opts = {}) ⇒ Array<(EventUpdateCancel200Response, Integer, Hash)>
Replay events Cancels all runs for a list of events.
602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 602 def event_update_cancel_with_http_info(tenant, cancel_event_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_update_cancel ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.event_update_cancel" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_update_cancel, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_update_cancel, the character length must be greater than or equal to 36.' end # verify the required parameter 'cancel_event_request' is set if @api_client.config.client_side_validation && cancel_event_request.nil? fail ArgumentError, "Missing the required parameter 'cancel_event_request' when calling EventApi.event_update_cancel" end # resource path local_var_path = '/api/v1/tenants/{tenant}/events/cancel'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(cancel_event_request) # return_type return_type = opts[:debug_return_type] || 'EventUpdateCancel200Response' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_update_cancel", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_update_cancel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#event_update_replay(tenant, replay_event_request, opts = {}) ⇒ EventList
Replay events Replays a list of events.
673 674 675 676 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 673 def event_update_replay(tenant, replay_event_request, opts = {}) data, _status_code, _headers = event_update_replay_with_http_info(tenant, replay_event_request, opts) data end |
#event_update_replay_with_http_info(tenant, replay_event_request, opts = {}) ⇒ Array<(EventList, Integer, Hash)>
Replay events Replays a list of events.
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 684 def event_update_replay_with_http_info(tenant, replay_event_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.event_update_replay ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.event_update_replay" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_update_replay, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.event_update_replay, the character length must be greater than or equal to 36.' end # verify the required parameter 'replay_event_request' is set if @api_client.config.client_side_validation && replay_event_request.nil? fail ArgumentError, "Missing the required parameter 'replay_event_request' when calling EventApi.event_update_replay" end # resource path local_var_path = '/api/v1/tenants/{tenant}/events/replay'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(replay_event_request) # return_type return_type = opts[:debug_return_type] || 'EventList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.event_update_replay", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#event_update_replay\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_event_get(tenant, v1_event, opts = {}) ⇒ V1Event
Get events Get an event by its id
755 756 757 758 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 755 def v1_event_get(tenant, v1_event, opts = {}) data, _status_code, _headers = v1_event_get_with_http_info(tenant, v1_event, opts) data end |
#v1_event_get_with_http_info(tenant, v1_event, opts = {}) ⇒ Array<(V1Event, Integer, Hash)>
Get events Get an event by its id
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 766 def v1_event_get_with_http_info(tenant, v1_event, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.v1_event_get ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.v1_event_get" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.v1_event_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.v1_event_get, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_event' is set if @api_client.config.client_side_validation && v1_event.nil? fail ArgumentError, "Missing the required parameter 'v1_event' when calling EventApi.v1_event_get" end if @api_client.config.client_side_validation && v1_event.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_event" when calling EventApi.v1_event_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_event.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_event" when calling EventApi.v1_event_get, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/events/{v1-event}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-event' + '}', CGI.escape(v1_event.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1Event' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.v1_event_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#v1_event_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_event_key_list(tenant, opts = {}) ⇒ EventKeyList
List event keys Lists all event keys for a tenant.
839 840 841 842 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 839 def v1_event_key_list(tenant, opts = {}) data, _status_code, _headers = v1_event_key_list_with_http_info(tenant, opts) data end |
#v1_event_key_list_with_http_info(tenant, opts = {}) ⇒ Array<(EventKeyList, Integer, Hash)>
List event keys Lists all event keys for a tenant.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 849 def v1_event_key_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.v1_event_key_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.v1_event_key_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.v1_event_key_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.v1_event_key_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/events/keys'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventKeyList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.v1_event_key_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#v1_event_key_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_event_list(tenant, opts = {}) ⇒ V1EventList
List events Lists all events for a tenant.
920 921 922 923 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 920 def v1_event_list(tenant, opts = {}) data, _status_code, _headers = v1_event_list_with_http_info(tenant, opts) data end |
#v1_event_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1EventList, Integer, Hash)>
List events Lists all events for a tenant.
940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/event_api.rb', line 940 def v1_event_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventApi.v1_event_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling EventApi.v1_event_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.v1_event_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling EventApi.v1_event_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/events'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'keys'] = @api_client.build_collection_param(opts[:'keys'], :multi) if !opts[:'keys'].nil? query_params[:'since'] = opts[:'since'] if !opts[:'since'].nil? query_params[:'until'] = opts[:'_until'] if !opts[:'_until'].nil? query_params[:'workflowIds'] = @api_client.build_collection_param(opts[:'workflow_ids'], :multi) if !opts[:'workflow_ids'].nil? query_params[:'workflowRunStatuses'] = @api_client.build_collection_param(opts[:'workflow_run_statuses'], :multi) if !opts[:'workflow_run_statuses'].nil? query_params[:'eventIds'] = @api_client.build_collection_param(opts[:'event_ids'], :multi) if !opts[:'event_ids'].nil? query_params[:'additionalMetadata'] = @api_client.build_collection_param(opts[:'additional_metadata'], :multi) if !opts[:'additional_metadata'].nil? query_params[:'scopes'] = @api_client.build_collection_param(opts[:'scopes'], :multi) if !opts[:'scopes'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1EventList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"EventApi.v1_event_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventApi#v1_event_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |