Class: HatchetSdkRest::FilterApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::FilterApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ FilterApi
constructor
A new instance of FilterApi.
-
#v1_filter_create(tenant, v1_create_filter_request, opts = {}) ⇒ V1Filter
Create a filter Create a new filter.
-
#v1_filter_create_with_http_info(tenant, v1_create_filter_request, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Create a filter Create a new filter.
-
#v1_filter_delete(tenant, v1_filter, opts = {}) ⇒ V1Filter
Delete a filter.
-
#v1_filter_delete_with_http_info(tenant, v1_filter, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Delete a filter.
-
#v1_filter_get(tenant, v1_filter, opts = {}) ⇒ V1Filter
Get a filter Get a filter by its id.
-
#v1_filter_get_with_http_info(tenant, v1_filter, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Get a filter Get a filter by its id.
-
#v1_filter_list(tenant, opts = {}) ⇒ V1FilterList
List filters Lists all filters for a tenant.
-
#v1_filter_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1FilterList, Integer, Hash)>
List filters Lists all filters for a tenant.
-
#v1_filter_update(tenant, v1_filter, v1_update_filter_request, opts = {}) ⇒ V1Filter
Update a filter.
-
#v1_filter_update_with_http_info(tenant, v1_filter, v1_update_filter_request, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Update a filter.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_filter_create(tenant, v1_create_filter_request, opts = {}) ⇒ V1Filter
Create a filter Create a new filter
28 29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 28 def v1_filter_create(tenant, v1_create_filter_request, opts = {}) data, _status_code, _headers = v1_filter_create_with_http_info(tenant, v1_create_filter_request, opts) data end |
#v1_filter_create_with_http_info(tenant, v1_create_filter_request, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Create a filter Create a new filter
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 39 def v1_filter_create_with_http_info(tenant, v1_create_filter_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FilterApi.v1_filter_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling FilterApi.v1_filter_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_create, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_create_filter_request' is set if @api_client.config.client_side_validation && v1_create_filter_request.nil? fail ArgumentError, "Missing the required parameter 'v1_create_filter_request' when calling FilterApi.v1_filter_create" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/filters'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_create_filter_request) # return_type return_type = opts[:debug_return_type] || 'V1Filter' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"FilterApi.v1_filter_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FilterApi#v1_filter_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_filter_delete(tenant, v1_filter, opts = {}) ⇒ V1Filter
Delete a filter
109 110 111 112 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 109 def v1_filter_delete(tenant, v1_filter, opts = {}) data, _status_code, _headers = v1_filter_delete_with_http_info(tenant, v1_filter, opts) data end |
#v1_filter_delete_with_http_info(tenant, v1_filter, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Delete a filter
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 119 def v1_filter_delete_with_http_info(tenant, v1_filter, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FilterApi.v1_filter_delete ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling FilterApi.v1_filter_delete" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_delete, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_delete, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_filter' is set if @api_client.config.client_side_validation && v1_filter.nil? fail ArgumentError, "Missing the required parameter 'v1_filter' when calling FilterApi.v1_filter_delete" end if @api_client.config.client_side_validation && v1_filter.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_filter" when calling FilterApi.v1_filter_delete, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_filter.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_filter" when calling FilterApi.v1_filter_delete, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/filters/{v1-filter}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-filter' + '}', CGI.escape(v1_filter.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1Filter' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"FilterApi.v1_filter_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FilterApi#v1_filter_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_filter_get(tenant, v1_filter, opts = {}) ⇒ V1Filter
Get a filter Get a filter by its id
193 194 195 196 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 193 def v1_filter_get(tenant, v1_filter, opts = {}) data, _status_code, _headers = v1_filter_get_with_http_info(tenant, v1_filter, opts) data end |
#v1_filter_get_with_http_info(tenant, v1_filter, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Get a filter Get a filter by its id
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 204 def v1_filter_get_with_http_info(tenant, v1_filter, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FilterApi.v1_filter_get ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling FilterApi.v1_filter_get" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_get, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_filter' is set if @api_client.config.client_side_validation && v1_filter.nil? fail ArgumentError, "Missing the required parameter 'v1_filter' when calling FilterApi.v1_filter_get" end if @api_client.config.client_side_validation && v1_filter.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_filter" when calling FilterApi.v1_filter_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_filter.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_filter" when calling FilterApi.v1_filter_get, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/filters/{v1-filter}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-filter' + '}', CGI.escape(v1_filter.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1Filter' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"FilterApi.v1_filter_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FilterApi#v1_filter_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_filter_list(tenant, opts = {}) ⇒ V1FilterList
List filters Lists all filters for a tenant.
281 282 283 284 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 281 def v1_filter_list(tenant, opts = {}) data, _status_code, _headers = v1_filter_list_with_http_info(tenant, opts) data end |
#v1_filter_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1FilterList, Integer, Hash)>
List filters Lists all filters for a tenant.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 295 def v1_filter_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FilterApi.v1_filter_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling FilterApi.v1_filter_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/filters'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'workflowIds'] = @api_client.build_collection_param(opts[:'workflow_ids'], :multi) if !opts[:'workflow_ids'].nil? query_params[:'scopes'] = @api_client.build_collection_param(opts[:'scopes'], :multi) if !opts[:'scopes'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1FilterList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"FilterApi.v1_filter_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FilterApi#v1_filter_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_filter_update(tenant, v1_filter, v1_update_filter_request, opts = {}) ⇒ V1Filter
Update a filter
361 362 363 364 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 361 def v1_filter_update(tenant, v1_filter, v1_update_filter_request, opts = {}) data, _status_code, _headers = v1_filter_update_with_http_info(tenant, v1_filter, v1_update_filter_request, opts) data end |
#v1_filter_update_with_http_info(tenant, v1_filter, v1_update_filter_request, opts = {}) ⇒ Array<(V1Filter, Integer, Hash)>
Update a filter
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/filter_api.rb', line 372 def v1_filter_update_with_http_info(tenant, v1_filter, v1_update_filter_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FilterApi.v1_filter_update ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling FilterApi.v1_filter_update" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_update, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling FilterApi.v1_filter_update, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_filter' is set if @api_client.config.client_side_validation && v1_filter.nil? fail ArgumentError, "Missing the required parameter 'v1_filter' when calling FilterApi.v1_filter_update" end if @api_client.config.client_side_validation && v1_filter.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_filter" when calling FilterApi.v1_filter_update, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_filter.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_filter" when calling FilterApi.v1_filter_update, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_update_filter_request' is set if @api_client.config.client_side_validation && v1_update_filter_request.nil? fail ArgumentError, "Missing the required parameter 'v1_update_filter_request' when calling FilterApi.v1_filter_update" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/filters/{v1-filter}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-filter' + '}', CGI.escape(v1_filter.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_update_filter_request) # return_type return_type = opts[:debug_return_type] || 'V1Filter' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"FilterApi.v1_filter_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FilterApi#v1_filter_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |