Class: HatchetSdkRest::GithubApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::GithubApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/github_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ GithubApi
constructor
A new instance of GithubApi.
-
#sns_update(tenant, event, opts = {}) ⇒ nil
Github app tenant webhook SNS event.
-
#sns_update_with_http_info(tenant, event, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Github app tenant webhook SNS event.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/github_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#sns_update(tenant, event, opts = {}) ⇒ nil
Github app tenant webhook SNS event
28 29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/github_api.rb', line 28 def sns_update(tenant, event, opts = {}) sns_update_with_http_info(tenant, event, opts) nil end |
#sns_update_with_http_info(tenant, event, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Github app tenant webhook SNS event
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/github_api.rb', line 39 def sns_update_with_http_info(tenant, event, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GithubApi.sns_update ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling GithubApi.sns_update" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling GithubApi.sns_update, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling GithubApi.sns_update, the character length must be greater than or equal to 36.' end # verify the required parameter 'event' is set if @api_client.config.client_side_validation && event.nil? fail ArgumentError, "Missing the required parameter 'event' when calling GithubApi.sns_update" end if @api_client.config.client_side_validation && event.to_s.length > 255 fail ArgumentError, 'invalid value for "event" when calling GithubApi.sns_update, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && event.to_s.length < 1 fail ArgumentError, 'invalid value for "event" when calling GithubApi.sns_update, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/api/v1/sns/{tenant}/{event}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'event' + '}', CGI.escape(event.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"GithubApi.sns_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GithubApi#sns_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |