Class: HatchetSdkRest::JobRun

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobRun

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::JobRun` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::JobRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'workflow_run_id')
    self.workflow_run_id = attributes[:'workflow_run_id']
  else
    self.workflow_run_id = nil
  end

  if attributes.key?(:'job_id')
    self.job_id = attributes[:'job_id']
  else
    self.job_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'workflow_run')
    self.workflow_run = attributes[:'workflow_run']
  end

  if attributes.key?(:'job')
    self.job = attributes[:'job']
  end

  if attributes.key?(:'ticker_id')
    self.ticker_id = attributes[:'ticker_id']
  end

  if attributes.key?(:'step_runs')
    if (value = attributes[:'step_runs']).is_a?(Array)
      self.step_runs = value
    end
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'finished_at')
    self.finished_at = attributes[:'finished_at']
  end

  if attributes.key?(:'timeout_at')
    self.timeout_at = attributes[:'timeout_at']
  end

  if attributes.key?(:'cancelled_at')
    self.cancelled_at = attributes[:'cancelled_at']
  end

  if attributes.key?(:'cancelled_reason')
    self.cancelled_reason = attributes[:'cancelled_reason']
  end

  if attributes.key?(:'cancelled_error')
    self.cancelled_error = attributes[:'cancelled_error']
  end
end

Instance Attribute Details

#cancelled_atObject

Returns the value of attribute cancelled_at.



44
45
46
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 44

def cancelled_at
  @cancelled_at
end

#cancelled_errorObject

Returns the value of attribute cancelled_error.



48
49
50
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 48

def cancelled_error
  @cancelled_error
end

#cancelled_reasonObject

Returns the value of attribute cancelled_reason.



46
47
48
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 46

def cancelled_reason
  @cancelled_reason
end

#finished_atObject

Returns the value of attribute finished_at.



40
41
42
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 40

def finished_at
  @finished_at
end

#jobObject

Returns the value of attribute job.



30
31
32
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 30

def job
  @job
end

#job_idObject

Returns the value of attribute job_id.



24
25
26
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 24

def job_id
  @job_id
end

#metadataObject

Returns the value of attribute metadata.



18
19
20
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 18

def 
  @metadata
end

#resultObject

Returns the value of attribute result.



36
37
38
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 36

def result
  @result
end

#started_atObject

Returns the value of attribute started_at.



38
39
40
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 38

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 26

def status
  @status
end

#step_runsObject

Returns the value of attribute step_runs.



34
35
36
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 34

def step_runs
  @step_runs
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 20

def tenant_id
  @tenant_id
end

#ticker_idObject

Returns the value of attribute ticker_id.



32
33
34
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 32

def ticker_id
  @ticker_id
end

#timeout_atObject

Returns the value of attribute timeout_at.



42
43
44
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 42

def timeout_at
  @timeout_at
end

#workflow_runObject

Returns the value of attribute workflow_run.



28
29
30
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 28

def workflow_run
  @workflow_run
end

#workflow_run_idObject

Returns the value of attribute workflow_run_id.



22
23
24
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 22

def workflow_run_id
  @workflow_run_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 377

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 73

def self.attribute_map
  {
    :'metadata' => :'metadata',
    :'tenant_id' => :'tenantId',
    :'workflow_run_id' => :'workflowRunId',
    :'job_id' => :'jobId',
    :'status' => :'status',
    :'workflow_run' => :'workflowRun',
    :'job' => :'job',
    :'ticker_id' => :'tickerId',
    :'step_runs' => :'stepRuns',
    :'result' => :'result',
    :'started_at' => :'startedAt',
    :'finished_at' => :'finishedAt',
    :'timeout_at' => :'timeoutAt',
    :'cancelled_at' => :'cancelledAt',
    :'cancelled_reason' => :'cancelledReason',
    :'cancelled_error' => :'cancelledError'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 353

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 105

def self.openapi_types
  {
    :'metadata' => :'APIResourceMeta',
    :'tenant_id' => :'String',
    :'workflow_run_id' => :'String',
    :'job_id' => :'String',
    :'status' => :'JobRunStatus',
    :'workflow_run' => :'WorkflowRun',
    :'job' => :'Job',
    :'ticker_id' => :'String',
    :'step_runs' => :'Array<StepRun>',
    :'result' => :'Object',
    :'started_at' => :'Time',
    :'finished_at' => :'Time',
    :'timeout_at' => :'Time',
    :'cancelled_at' => :'Time',
    :'cancelled_reason' => :'String',
    :'cancelled_error' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 317

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      tenant_id == o.tenant_id &&
      workflow_run_id == o.workflow_run_id &&
      job_id == o.job_id &&
      status == o.status &&
      workflow_run == o.workflow_run &&
      job == o.job &&
      ticker_id == o.ticker_id &&
      step_runs == o.step_runs &&
      result == o.result &&
      started_at == o.started_at &&
      finished_at == o.finished_at &&
      timeout_at == o.timeout_at &&
      cancelled_at == o.cancelled_at &&
      cancelled_reason == o.cancelled_reason &&
      cancelled_error == o.cancelled_error
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 448

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


340
341
342
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 340

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



346
347
348
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 346

def hash
  [, tenant_id, workflow_run_id, job_id, status, workflow_run, job, ticker_id, step_runs, result, started_at, finished_at, timeout_at, cancelled_at, cancelled_reason, cancelled_error].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 227

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @workflow_run_id.nil?
    invalid_properties.push('invalid value for "workflow_run_id", workflow_run_id cannot be nil.')
  end

  if @job_id.nil?
    invalid_properties.push('invalid value for "job_id", job_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 424

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 430

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



418
419
420
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 418

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
259
260
261
262
263
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/job_run.rb', line 255

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metadata.nil?
  return false if @tenant_id.nil?
  return false if @workflow_run_id.nil?
  return false if @job_id.nil?
  return false if @status.nil?
  true
end