Class: HatchetSdkRest::MetadataApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::MetadataApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cloud_metadata_get(opts = {}) ⇒ APIErrors
Get cloud metadata Gets metadata for the Hatchet cloud instance.
-
#cloud_metadata_get_with_http_info(opts = {}) ⇒ Array<(APIErrors, Integer, Hash)>
Get cloud metadata Gets metadata for the Hatchet cloud instance.
-
#initialize(api_client = ApiClient.default) ⇒ MetadataApi
constructor
A new instance of MetadataApi.
-
#metadata_get(opts = {}) ⇒ APIMeta
Get metadata Gets metadata for the Hatchet instance.
-
#metadata_get_with_http_info(opts = {}) ⇒ Array<(APIMeta, Integer, Hash)>
Get metadata Gets metadata for the Hatchet instance.
-
#metadata_list_integrations(opts = {}) ⇒ Array<APIMetaIntegration>
List integrations List all integrations.
-
#metadata_list_integrations_with_http_info(opts = {}) ⇒ Array<(Array<APIMetaIntegration>, Integer, Hash)>
List integrations List all integrations.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MetadataApi
Returns a new instance of MetadataApi.
19 20 21 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cloud_metadata_get(opts = {}) ⇒ APIErrors
Get cloud metadata Gets metadata for the Hatchet cloud instance
26 27 28 29 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 26 def (opts = {}) data, _status_code, _headers = (opts) data end |
#cloud_metadata_get_with_http_info(opts = {}) ⇒ Array<(APIErrors, Integer, Hash)>
Get cloud metadata Gets metadata for the Hatchet cloud instance
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 35 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetadataApi.cloud_metadata_get ...' end # resource path local_var_path = '/api/v1/cloud/metadata' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'APIErrors' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"MetadataApi.cloud_metadata_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetadataApi#cloud_metadata_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#metadata_get(opts = {}) ⇒ APIMeta
Get metadata Gets metadata for the Hatchet instance
83 84 85 86 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 83 def (opts = {}) data, _status_code, _headers = (opts) data end |
#metadata_get_with_http_info(opts = {}) ⇒ Array<(APIMeta, Integer, Hash)>
Get metadata Gets metadata for the Hatchet instance
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 92 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetadataApi.metadata_get ...' end # resource path local_var_path = '/api/v1/meta' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'APIMeta' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"MetadataApi.metadata_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetadataApi#metadata_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#metadata_list_integrations(opts = {}) ⇒ Array<APIMetaIntegration>
List integrations List all integrations
140 141 142 143 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 140 def (opts = {}) data, _status_code, _headers = (opts) data end |
#metadata_list_integrations_with_http_info(opts = {}) ⇒ Array<(Array<APIMetaIntegration>, Integer, Hash)>
List integrations List all integrations
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/metadata_api.rb', line 149 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetadataApi.metadata_list_integrations ...' end # resource path local_var_path = '/api/v1/meta/integrations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<APIMetaIntegration>' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"MetadataApi.metadata_list_integrations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetadataApi#metadata_list_integrations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |