Class: HatchetSdkRest::OperatorApi

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ OperatorApi

Returns a new instance of OperatorApi.



19
20
21
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#v1_http_operator_create(tenant, v1_create_http_operator_request, opts = {}) ⇒ V1HTTPOperator

Create an HTTP operator Create a new HTTP operator

Parameters:

  • tenant (String)

    The tenant id

  • v1_create_http_operator_request (V1CreateHTTPOperatorRequest)

    The input to the HTTP operator creation

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 28

def v1_http_operator_create(tenant, v1_create_http_operator_request, opts = {})
  data, _status_code, _headers = v1_http_operator_create_with_http_info(tenant, v1_create_http_operator_request, opts)
  data
end

#v1_http_operator_create_with_http_info(tenant, v1_create_http_operator_request, opts = {}) ⇒ Array<(V1HTTPOperator, Integer, Hash)>

Create an HTTP operator Create a new HTTP operator

Parameters:

  • tenant (String)

    The tenant id

  • v1_create_http_operator_request (V1CreateHTTPOperatorRequest)

    The input to the HTTP operator creation

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1HTTPOperator, Integer, Hash)>)

    V1HTTPOperator data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 39

def v1_http_operator_create_with_http_info(tenant, v1_create_http_operator_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperatorApi.v1_http_operator_create ...'
  end
  # verify the required parameter 'tenant' is set
  if @api_client.config.client_side_validation && tenant.nil?
    fail ArgumentError, "Missing the required parameter 'tenant' when calling OperatorApi.v1_http_operator_create"
  end
  if @api_client.config.client_side_validation && tenant.to_s.length > 36
    fail ArgumentError, 'invalid value for "tenant" when calling OperatorApi.v1_http_operator_create, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && tenant.to_s.length < 36
    fail ArgumentError, 'invalid value for "tenant" when calling OperatorApi.v1_http_operator_create, the character length must be greater than or equal to 36.'
  end

  # verify the required parameter 'v1_create_http_operator_request' is set
  if @api_client.config.client_side_validation && v1_create_http_operator_request.nil?
    fail ArgumentError, "Missing the required parameter 'v1_create_http_operator_request' when calling OperatorApi.v1_http_operator_create"
  end
  # resource path
  local_var_path = '/api/v1/stable/tenants/{tenant}/operators/http'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_create_http_operator_request)

  # return_type
  return_type = opts[:debug_return_type] || 'V1HTTPOperator'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth']

  new_options = opts.merge(
    :operation => :"OperatorApi.v1_http_operator_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperatorApi#v1_http_operator_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v1_http_operator_delete(v1_http_operator, opts = {}) ⇒ V1HTTPOperator

Delete an HTTP operator Delete an HTTP operator

Parameters:

  • v1_http_operator (String)

    The id of the HTTP operator to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



109
110
111
112
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 109

def v1_http_operator_delete(v1_http_operator, opts = {})
  data, _status_code, _headers = v1_http_operator_delete_with_http_info(v1_http_operator, opts)
  data
end

#v1_http_operator_delete_with_http_info(v1_http_operator, opts = {}) ⇒ Array<(V1HTTPOperator, Integer, Hash)>

Delete an HTTP operator Delete an HTTP operator

Parameters:

  • v1_http_operator (String)

    The id of the HTTP operator to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1HTTPOperator, Integer, Hash)>)

    V1HTTPOperator data, response status code and response headers



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 119

def v1_http_operator_delete_with_http_info(v1_http_operator, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperatorApi.v1_http_operator_delete ...'
  end
  # verify the required parameter 'v1_http_operator' is set
  if @api_client.config.client_side_validation && v1_http_operator.nil?
    fail ArgumentError, "Missing the required parameter 'v1_http_operator' when calling OperatorApi.v1_http_operator_delete"
  end
  if @api_client.config.client_side_validation && v1_http_operator.to_s.length > 36
    fail ArgumentError, 'invalid value for "v1_http_operator" when calling OperatorApi.v1_http_operator_delete, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && v1_http_operator.to_s.length < 36
    fail ArgumentError, 'invalid value for "v1_http_operator" when calling OperatorApi.v1_http_operator_delete, the character length must be greater than or equal to 36.'
  end

  # resource path
  local_var_path = '/api/v1/stable/operators/http/{v1-http-operator}'.sub('{' + 'v1-http-operator' + '}', CGI.escape(v1_http_operator.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'V1HTTPOperator'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth']

  new_options = opts.merge(
    :operation => :"OperatorApi.v1_http_operator_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperatorApi#v1_http_operator_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v1_http_operator_get(v1_http_operator, opts = {}) ⇒ V1HTTPOperator

Get an HTTP operator Get an HTTP operator by its id

Parameters:

  • v1_http_operator (String)

    The HTTP operator id

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



180
181
182
183
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 180

def v1_http_operator_get(v1_http_operator, opts = {})
  data, _status_code, _headers = v1_http_operator_get_with_http_info(v1_http_operator, opts)
  data
end

#v1_http_operator_get_with_http_info(v1_http_operator, opts = {}) ⇒ Array<(V1HTTPOperator, Integer, Hash)>

Get an HTTP operator Get an HTTP operator by its id

Parameters:

  • v1_http_operator (String)

    The HTTP operator id

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1HTTPOperator, Integer, Hash)>)

    V1HTTPOperator data, response status code and response headers



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 190

def v1_http_operator_get_with_http_info(v1_http_operator, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperatorApi.v1_http_operator_get ...'
  end
  # verify the required parameter 'v1_http_operator' is set
  if @api_client.config.client_side_validation && v1_http_operator.nil?
    fail ArgumentError, "Missing the required parameter 'v1_http_operator' when calling OperatorApi.v1_http_operator_get"
  end
  if @api_client.config.client_side_validation && v1_http_operator.to_s.length > 36
    fail ArgumentError, 'invalid value for "v1_http_operator" when calling OperatorApi.v1_http_operator_get, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && v1_http_operator.to_s.length < 36
    fail ArgumentError, 'invalid value for "v1_http_operator" when calling OperatorApi.v1_http_operator_get, the character length must be greater than or equal to 36.'
  end

  # resource path
  local_var_path = '/api/v1/stable/operators/http/{v1-http-operator}'.sub('{' + 'v1-http-operator' + '}', CGI.escape(v1_http_operator.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'V1HTTPOperator'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth']

  new_options = opts.merge(
    :operation => :"OperatorApi.v1_http_operator_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperatorApi#v1_http_operator_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v1_http_operator_list(tenant, opts = {}) ⇒ V1HTTPOperatorList

List HTTP operators Lists all HTTP operators for a tenant.

Parameters:

  • tenant (String)

    The tenant id

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The number to skip

  • :limit (Integer)

    The number to limit by

Returns:



253
254
255
256
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 253

def v1_http_operator_list(tenant, opts = {})
  data, _status_code, _headers = v1_http_operator_list_with_http_info(tenant, opts)
  data
end

#v1_http_operator_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1HTTPOperatorList, Integer, Hash)>

List HTTP operators Lists all HTTP operators for a tenant.

Parameters:

  • tenant (String)

    The tenant id

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The number to skip

  • :limit (Integer)

    The number to limit by

Returns:

  • (Array<(V1HTTPOperatorList, Integer, Hash)>)

    V1HTTPOperatorList data, response status code and response headers



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 265

def v1_http_operator_list_with_http_info(tenant, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperatorApi.v1_http_operator_list ...'
  end
  # verify the required parameter 'tenant' is set
  if @api_client.config.client_side_validation && tenant.nil?
    fail ArgumentError, "Missing the required parameter 'tenant' when calling OperatorApi.v1_http_operator_list"
  end
  if @api_client.config.client_side_validation && tenant.to_s.length > 36
    fail ArgumentError, 'invalid value for "tenant" when calling OperatorApi.v1_http_operator_list, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && tenant.to_s.length < 36
    fail ArgumentError, 'invalid value for "tenant" when calling OperatorApi.v1_http_operator_list, the character length must be greater than or equal to 36.'
  end

  # resource path
  local_var_path = '/api/v1/stable/tenants/{tenant}/operators/http'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'V1HTTPOperatorList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth']

  new_options = opts.merge(
    :operation => :"OperatorApi.v1_http_operator_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperatorApi#v1_http_operator_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v1_http_operator_update(v1_http_operator, v1_update_http_operator_request, opts = {}) ⇒ V1HTTPOperator

Update an HTTP operator Update an HTTP operator

Parameters:

  • v1_http_operator (String)

    The id of the HTTP operator to update

  • v1_update_http_operator_request (V1UpdateHTTPOperatorRequest)

    The fields to update on the HTTP operator

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



329
330
331
332
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 329

def v1_http_operator_update(v1_http_operator, v1_update_http_operator_request, opts = {})
  data, _status_code, _headers = v1_http_operator_update_with_http_info(v1_http_operator, v1_update_http_operator_request, opts)
  data
end

#v1_http_operator_update_with_http_info(v1_http_operator, v1_update_http_operator_request, opts = {}) ⇒ Array<(V1HTTPOperator, Integer, Hash)>

Update an HTTP operator Update an HTTP operator

Parameters:

  • v1_http_operator (String)

    The id of the HTTP operator to update

  • v1_update_http_operator_request (V1UpdateHTTPOperatorRequest)

    The fields to update on the HTTP operator

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1HTTPOperator, Integer, Hash)>)

    V1HTTPOperator data, response status code and response headers



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/operator_api.rb', line 340

def v1_http_operator_update_with_http_info(v1_http_operator, v1_update_http_operator_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperatorApi.v1_http_operator_update ...'
  end
  # verify the required parameter 'v1_http_operator' is set
  if @api_client.config.client_side_validation && v1_http_operator.nil?
    fail ArgumentError, "Missing the required parameter 'v1_http_operator' when calling OperatorApi.v1_http_operator_update"
  end
  if @api_client.config.client_side_validation && v1_http_operator.to_s.length > 36
    fail ArgumentError, 'invalid value for "v1_http_operator" when calling OperatorApi.v1_http_operator_update, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && v1_http_operator.to_s.length < 36
    fail ArgumentError, 'invalid value for "v1_http_operator" when calling OperatorApi.v1_http_operator_update, the character length must be greater than or equal to 36.'
  end

  # verify the required parameter 'v1_update_http_operator_request' is set
  if @api_client.config.client_side_validation && v1_update_http_operator_request.nil?
    fail ArgumentError, "Missing the required parameter 'v1_update_http_operator_request' when calling OperatorApi.v1_http_operator_update"
  end
  # resource path
  local_var_path = '/api/v1/stable/operators/http/{v1-http-operator}'.sub('{' + 'v1-http-operator' + '}', CGI.escape(v1_http_operator.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_update_http_operator_request)

  # return_type
  return_type = opts[:debug_return_type] || 'V1HTTPOperator'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth']

  new_options = opts.merge(
    :operation => :"OperatorApi.v1_http_operator_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperatorApi#v1_http_operator_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end