Class: HatchetSdkRest::OtelSpan
- Inherits:
-
Object
- Object
- HatchetSdkRest::OtelSpan
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#duration_ns ⇒ Object
Returns the value of attribute duration_ns.
-
#parent_span_id ⇒ Object
Returns the value of attribute parent_span_id.
-
#resource_attributes ⇒ Object
Returns the value of attribute resource_attributes.
-
#retry_count ⇒ Object
Returns the value of attribute retry_count.
-
#scope_name ⇒ Object
Returns the value of attribute scope_name.
-
#scope_version ⇒ Object
Returns the value of attribute scope_version.
-
#service_name ⇒ Object
Returns the value of attribute service_name.
-
#span_attributes ⇒ Object
Returns the value of attribute span_attributes.
-
#span_id ⇒ Object
Returns the value of attribute span_id.
-
#span_kind ⇒ Object
Returns the value of attribute span_kind.
-
#span_name ⇒ Object
Returns the value of attribute span_name.
-
#status_code ⇒ Object
Returns the value of attribute status_code.
-
#status_message ⇒ Object
Returns the value of attribute status_message.
-
#trace_id ⇒ Object
Returns the value of attribute trace_id.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OtelSpan
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OtelSpan
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::OtelSpan` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::OtelSpan`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'trace_id') self.trace_id = attributes[:'trace_id'] else self.trace_id = nil end if attributes.key?(:'span_id') self.span_id = attributes[:'span_id'] else self.span_id = nil end if attributes.key?(:'span_name') self.span_name = attributes[:'span_name'] else self.span_name = nil end if attributes.key?(:'span_kind') self.span_kind = attributes[:'span_kind'] else self.span_kind = nil end if attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] else self.service_name = nil end if attributes.key?(:'status_code') self.status_code = attributes[:'status_code'] else self.status_code = nil end if attributes.key?(:'duration_ns') self.duration_ns = attributes[:'duration_ns'] else self.duration_ns = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'retry_count') self.retry_count = attributes[:'retry_count'] else self.retry_count = nil end if attributes.key?(:'parent_span_id') self.parent_span_id = attributes[:'parent_span_id'] end if attributes.key?(:'status_message') self. = attributes[:'status_message'] end if attributes.key?(:'resource_attributes') if (value = attributes[:'resource_attributes']).is_a?(Hash) self.resource_attributes = value end end if attributes.key?(:'span_attributes') if (value = attributes[:'span_attributes']).is_a?(Hash) self.span_attributes = value end end if attributes.key?(:'scope_name') self.scope_name = attributes[:'scope_name'] end if attributes.key?(:'scope_version') self.scope_version = attributes[:'scope_version'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
32 33 34 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 32 def created_at @created_at end |
#duration_ns ⇒ Object
Returns the value of attribute duration_ns.
30 31 32 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 30 def duration_ns @duration_ns end |
#parent_span_id ⇒ Object
Returns the value of attribute parent_span_id.
36 37 38 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 36 def parent_span_id @parent_span_id end |
#resource_attributes ⇒ Object
Returns the value of attribute resource_attributes.
40 41 42 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 40 def resource_attributes @resource_attributes end |
#retry_count ⇒ Object
Returns the value of attribute retry_count.
34 35 36 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 34 def retry_count @retry_count end |
#scope_name ⇒ Object
Returns the value of attribute scope_name.
44 45 46 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 44 def scope_name @scope_name end |
#scope_version ⇒ Object
Returns the value of attribute scope_version.
46 47 48 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 46 def scope_version @scope_version end |
#service_name ⇒ Object
Returns the value of attribute service_name.
26 27 28 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 26 def service_name @service_name end |
#span_attributes ⇒ Object
Returns the value of attribute span_attributes.
42 43 44 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 42 def span_attributes @span_attributes end |
#span_id ⇒ Object
Returns the value of attribute span_id.
20 21 22 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 20 def span_id @span_id end |
#span_kind ⇒ Object
Returns the value of attribute span_kind.
24 25 26 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 24 def span_kind @span_kind end |
#span_name ⇒ Object
Returns the value of attribute span_name.
22 23 24 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 22 def span_name @span_name end |
#status_code ⇒ Object
Returns the value of attribute status_code.
28 29 30 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 28 def status_code @status_code end |
#status_message ⇒ Object
Returns the value of attribute status_message.
38 39 40 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 38 def @status_message end |
#trace_id ⇒ Object
Returns the value of attribute trace_id.
18 19 20 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 18 def trace_id @trace_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 438 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = HatchetSdkRest.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 71 def self.attribute_map { :'trace_id' => :'traceId', :'span_id' => :'spanId', :'span_name' => :'spanName', :'span_kind' => :'spanKind', :'service_name' => :'serviceName', :'status_code' => :'statusCode', :'duration_ns' => :'durationNs', :'created_at' => :'createdAt', :'retry_count' => :'retryCount', :'parent_span_id' => :'parentSpanId', :'status_message' => :'statusMessage', :'resource_attributes' => :'resourceAttributes', :'span_attributes' => :'spanAttributes', :'scope_name' => :'scopeName', :'scope_version' => :'scopeVersion' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 414 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 102 def self.openapi_types { :'trace_id' => :'String', :'span_id' => :'String', :'span_name' => :'String', :'span_kind' => :'OtelSpanKind', :'service_name' => :'String', :'status_code' => :'OtelStatusCode', :'duration_ns' => :'Integer', :'created_at' => :'Time', :'retry_count' => :'Integer', :'parent_span_id' => :'String', :'status_message' => :'String', :'resource_attributes' => :'Hash<String, String>', :'span_attributes' => :'Hash<String, String>', :'scope_name' => :'String', :'scope_version' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 379 def ==(o) return true if self.equal?(o) self.class == o.class && trace_id == o.trace_id && span_id == o.span_id && span_name == o.span_name && span_kind == o.span_kind && service_name == o.service_name && status_code == o.status_code && duration_ns == o.duration_ns && created_at == o.created_at && retry_count == o.retry_count && parent_span_id == o.parent_span_id && == o. && resource_attributes == o.resource_attributes && span_attributes == o.span_attributes && scope_name == o.scope_name && scope_version == o.scope_version end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 509 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
401 402 403 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 401 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
407 408 409 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 407 def hash [trace_id, span_id, span_name, span_kind, service_name, status_code, duration_ns, created_at, retry_count, parent_span_id, , resource_attributes, span_attributes, scope_name, scope_version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 229 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @trace_id.nil? invalid_properties.push('invalid value for "trace_id", trace_id cannot be nil.') end if @span_id.nil? invalid_properties.push('invalid value for "span_id", span_id cannot be nil.') end if @span_name.nil? invalid_properties.push('invalid value for "span_name", span_name cannot be nil.') end if @span_kind.nil? invalid_properties.push('invalid value for "span_kind", span_kind cannot be nil.') end if @service_name.nil? invalid_properties.push('invalid value for "service_name", service_name cannot be nil.') end if @status_code.nil? invalid_properties.push('invalid value for "status_code", status_code cannot be nil.') end if @duration_ns.nil? invalid_properties.push('invalid value for "duration_ns", duration_ns cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @retry_count.nil? invalid_properties.push('invalid value for "retry_count", retry_count cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
485 486 487 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 485 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 491 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
479 480 481 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 479 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/otel_span.rb', line 273 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @trace_id.nil? return false if @span_id.nil? return false if @span_name.nil? return false if @span_kind.nil? return false if @service_name.nil? return false if @status_code.nil? return false if @duration_ns.nil? return false if @created_at.nil? return false if @retry_count.nil? true end |