Class: HatchetSdkRest::RateLimitsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/rate_limits_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RateLimitsApi



19
20
21
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/rate_limits_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/rate_limits_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#rate_limit_delete(tenant, key, opts = {}) ⇒ nil

Delete rate limit Delete a rate limit for a tenant.



28
29
30
31
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/rate_limits_api.rb', line 28

def rate_limit_delete(tenant, key, opts = {})
  rate_limit_delete_with_http_info(tenant, key, opts)
  nil
end

#rate_limit_delete_with_http_info(tenant, key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete rate limit Delete a rate limit for a tenant.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/rate_limits_api.rb', line 39

def rate_limit_delete_with_http_info(tenant, key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RateLimitsApi.rate_limit_delete ...'
  end
  # verify the required parameter 'tenant' is set
  if @api_client.config.client_side_validation && tenant.nil?
    fail ArgumentError, "Missing the required parameter 'tenant' when calling RateLimitsApi.rate_limit_delete"
  end
  if @api_client.config.client_side_validation && tenant.to_s.length > 36
    fail ArgumentError, 'invalid value for "tenant" when calling RateLimitsApi.rate_limit_delete, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && tenant.to_s.length < 36
    fail ArgumentError, 'invalid value for "tenant" when calling RateLimitsApi.rate_limit_delete, the character length must be greater than or equal to 36.'
  end

  # verify the required parameter 'key' is set
  if @api_client.config.client_side_validation && key.nil?
    fail ArgumentError, "Missing the required parameter 'key' when calling RateLimitsApi.rate_limit_delete"
  end
  # resource path
  local_var_path = '/api/v1/tenants/{tenant}/rate-limits'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'key'] = key

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth']

  new_options = opts.merge(
    :operation => :"RateLimitsApi.rate_limit_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RateLimitsApi#rate_limit_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#rate_limit_list(tenant, opts = {}) ⇒ RateLimitList

List rate limits Lists all rate limits for a tenant.

Options Hash (opts):

  • :offset (Integer)

    The number to skip

  • :limit (Integer)

    The number to limit by

  • :search (String)

    The search query to filter for

  • :order_by_field (RateLimitOrderByField)

    What to order by

  • :order_by_direction (RateLimitOrderByDirection)

    The order direction



110
111
112
113
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/rate_limits_api.rb', line 110

def rate_limit_list(tenant, opts = {})
  data, _status_code, _headers = rate_limit_list_with_http_info(tenant, opts)
  data
end

#rate_limit_list_with_http_info(tenant, opts = {}) ⇒ Array<(RateLimitList, Integer, Hash)>

List rate limits Lists all rate limits for a tenant.

Options Hash (opts):

  • :offset (Integer)

    The number to skip

  • :limit (Integer)

    The number to limit by

  • :search (String)

    The search query to filter for

  • :order_by_field (RateLimitOrderByField)

    What to order by

  • :order_by_direction (RateLimitOrderByDirection)

    The order direction



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/rate_limits_api.rb', line 125

def rate_limit_list_with_http_info(tenant, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RateLimitsApi.rate_limit_list ...'
  end
  # verify the required parameter 'tenant' is set
  if @api_client.config.client_side_validation && tenant.nil?
    fail ArgumentError, "Missing the required parameter 'tenant' when calling RateLimitsApi.rate_limit_list"
  end
  if @api_client.config.client_side_validation && tenant.to_s.length > 36
    fail ArgumentError, 'invalid value for "tenant" when calling RateLimitsApi.rate_limit_list, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && tenant.to_s.length < 36
    fail ArgumentError, 'invalid value for "tenant" when calling RateLimitsApi.rate_limit_list, the character length must be greater than or equal to 36.'
  end

  # resource path
  local_var_path = '/api/v1/tenants/{tenant}/rate-limits'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?
  query_params[:'orderByField'] = opts[:'order_by_field'] if !opts[:'order_by_field'].nil?
  query_params[:'orderByDirection'] = opts[:'order_by_direction'] if !opts[:'order_by_direction'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RateLimitList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth']

  new_options = opts.merge(
    :operation => :"RateLimitsApi.rate_limit_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RateLimitsApi#rate_limit_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end