Class: HatchetSdkRest::RecentStepRuns
- Inherits:
-
Object
- Object
- HatchetSdkRest::RecentStepRuns
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action_id ⇒ Object
The action id.
-
#cancelled_at ⇒ Object
Returns the value of attribute cancelled_at.
-
#finished_at ⇒ Object
Returns the value of attribute finished_at.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#workflow_run_id ⇒ Object
Returns the value of attribute workflow_run_id.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecentStepRuns
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RecentStepRuns
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::RecentStepRuns` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::RecentStepRuns`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'metadata') self. = attributes[:'metadata'] else self. = nil end if attributes.key?(:'action_id') self.action_id = attributes[:'action_id'] else self.action_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'workflow_run_id') self.workflow_run_id = attributes[:'workflow_run_id'] else self.workflow_run_id = nil end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'finished_at') self.finished_at = attributes[:'finished_at'] end if attributes.key?(:'cancelled_at') self.cancelled_at = attributes[:'cancelled_at'] end end |
Instance Attribute Details
#action_id ⇒ Object
The action id.
21 22 23 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 21 def action_id @action_id end |
#cancelled_at ⇒ Object
Returns the value of attribute cancelled_at.
31 32 33 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 31 def cancelled_at @cancelled_at end |
#finished_at ⇒ Object
Returns the value of attribute finished_at.
29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 29 def finished_at @finished_at end |
#metadata ⇒ Object
Returns the value of attribute metadata.
18 19 20 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 18 def @metadata end |
#started_at ⇒ Object
Returns the value of attribute started_at.
27 28 29 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 27 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
23 24 25 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 23 def status @status end |
#workflow_run_id ⇒ Object
Returns the value of attribute workflow_run_id.
25 26 27 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 25 def workflow_run_id @workflow_run_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 278 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = HatchetSdkRest.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 56 def self.attribute_map { :'metadata' => :'metadata', :'action_id' => :'actionId', :'status' => :'status', :'workflow_run_id' => :'workflowRunId', :'started_at' => :'startedAt', :'finished_at' => :'finishedAt', :'cancelled_at' => :'cancelledAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 254 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 79 def self.openapi_types { :'metadata' => :'APIResourceMeta', :'action_id' => :'String', :'status' => :'StepRunStatus', :'workflow_run_id' => :'String', :'started_at' => :'Time', :'finished_at' => :'Time', :'cancelled_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && action_id == o.action_id && status == o.status && workflow_run_id == o.workflow_run_id && started_at == o.started_at && finished_at == o.finished_at && cancelled_at == o.cancelled_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 349 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
241 242 243 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 241 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
247 248 249 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 247 def hash [, action_id, status, workflow_run_id, started_at, finished_at, cancelled_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @metadata.nil? invalid_properties.push('invalid value for "metadata", metadata cannot be nil.') end if @action_id.nil? invalid_properties.push('invalid value for "action_id", action_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @workflow_run_id.nil? invalid_properties.push('invalid value for "workflow_run_id", workflow_run_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
325 326 327 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 325 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
319 320 321 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 319 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/recent_step_runs.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @metadata.nil? return false if @action_id.nil? return false if @status.nil? return false if @workflow_run_id.nil? true end |