Class: HatchetSdkRest::SNSApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::SNSApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SNSApi
constructor
A new instance of SNSApi.
-
#sns_create(tenant, opts = {}) ⇒ SNSIntegration
Create SNS integration Create SNS integration.
-
#sns_create_with_http_info(tenant, opts = {}) ⇒ Array<(SNSIntegration, Integer, Hash)>
Create SNS integration Create SNS integration.
-
#sns_delete(sns, opts = {}) ⇒ nil
Delete SNS integration Delete SNS integration.
-
#sns_delete_with_http_info(sns, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete SNS integration Delete SNS integration.
-
#sns_list(tenant, opts = {}) ⇒ ListSNSIntegrations
List SNS integrations List SNS integrations.
-
#sns_list_with_http_info(tenant, opts = {}) ⇒ Array<(ListSNSIntegrations, Integer, Hash)>
List SNS integrations List SNS integrations.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#sns_create(tenant, opts = {}) ⇒ SNSIntegration
Create SNS integration Create SNS integration
28 29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb', line 28 def sns_create(tenant, opts = {}) data, _status_code, _headers = sns_create_with_http_info(tenant, opts) data end |
#sns_create_with_http_info(tenant, opts = {}) ⇒ Array<(SNSIntegration, Integer, Hash)>
Create SNS integration Create SNS integration
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb', line 39 def sns_create_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SNSApi.sns_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling SNSApi.sns_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling SNSApi.sns_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling SNSApi.sns_create, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/sns'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_sns_integration_request']) # return_type return_type = opts[:debug_return_type] || 'SNSIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"SNSApi.sns_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SNSApi#sns_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sns_delete(sns, opts = {}) ⇒ nil
Delete SNS integration Delete SNS integration
105 106 107 108 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb', line 105 def sns_delete(sns, opts = {}) sns_delete_with_http_info(sns, opts) nil end |
#sns_delete_with_http_info(sns, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete SNS integration Delete SNS integration
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb', line 115 def sns_delete_with_http_info(sns, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SNSApi.sns_delete ...' end # verify the required parameter 'sns' is set if @api_client.config.client_side_validation && sns.nil? fail ArgumentError, "Missing the required parameter 'sns' when calling SNSApi.sns_delete" end if @api_client.config.client_side_validation && sns.to_s.length > 36 fail ArgumentError, 'invalid value for "sns" when calling SNSApi.sns_delete, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && sns.to_s.length < 36 fail ArgumentError, 'invalid value for "sns" when calling SNSApi.sns_delete, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/sns/{sns}'.sub('{' + 'sns' + '}', CGI.escape(sns.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"SNSApi.sns_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SNSApi#sns_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sns_list(tenant, opts = {}) ⇒ ListSNSIntegrations
List SNS integrations List SNS integrations
176 177 178 179 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb', line 176 def sns_list(tenant, opts = {}) data, _status_code, _headers = sns_list_with_http_info(tenant, opts) data end |
#sns_list_with_http_info(tenant, opts = {}) ⇒ Array<(ListSNSIntegrations, Integer, Hash)>
List SNS integrations List SNS integrations
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/sns_api.rb', line 186 def sns_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SNSApi.sns_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling SNSApi.sns_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling SNSApi.sns_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling SNSApi.sns_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/sns'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListSNSIntegrations' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"SNSApi.sns_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SNSApi#sns_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |