Class: HatchetSdkRest::ScheduledWorkflows

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ScheduledWorkflows

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::ScheduledWorkflows` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::ScheduledWorkflows`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'workflow_version_id')
    self.workflow_version_id = attributes[:'workflow_version_id']
  else
    self.workflow_version_id = nil
  end

  if attributes.key?(:'workflow_id')
    self.workflow_id = attributes[:'workflow_id']
  else
    self.workflow_id = nil
  end

  if attributes.key?(:'workflow_name')
    self.workflow_name = attributes[:'workflow_name']
  else
    self.workflow_name = nil
  end

  if attributes.key?(:'trigger_at')
    self.trigger_at = attributes[:'trigger_at']
  else
    self.trigger_at = nil
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'input')
    if (value = attributes[:'input']).is_a?(Hash)
      self.input = value
    end
  end

  if attributes.key?(:'additional_metadata')
    if (value = attributes[:'additional_metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'workflow_run_created_at')
    self.workflow_run_created_at = attributes[:'workflow_run_created_at']
  end

  if attributes.key?(:'workflow_run_name')
    self.workflow_run_name = attributes[:'workflow_run_name']
  end

  if attributes.key?(:'workflow_run_status')
    self.workflow_run_status = attributes[:'workflow_run_status']
  end

  if attributes.key?(:'workflow_run_id')
    self.workflow_run_id = attributes[:'workflow_run_id']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end
end

Instance Attribute Details

#additional_metadataObject

Returns the value of attribute additional_metadata.



34
35
36
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 34

def 
  @additional_metadata
end

#inputObject

Returns the value of attribute input.



32
33
34
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 32

def input
  @input
end

#metadataObject

Returns the value of attribute metadata.



18
19
20
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 18

def 
  @metadata
end

#methodObject

Returns the value of attribute method.



30
31
32
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 30

def method
  @method
end

#priorityObject

Returns the value of attribute priority.



44
45
46
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 44

def priority
  @priority
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 20

def tenant_id
  @tenant_id
end

#trigger_atObject

Returns the value of attribute trigger_at.



28
29
30
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 28

def trigger_at
  @trigger_at
end

#workflow_idObject

Returns the value of attribute workflow_id.



24
25
26
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 24

def workflow_id
  @workflow_id
end

#workflow_nameObject

Returns the value of attribute workflow_name.



26
27
28
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 26

def workflow_name
  @workflow_name
end

#workflow_run_created_atObject

Returns the value of attribute workflow_run_created_at.



36
37
38
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 36

def workflow_run_created_at
  @workflow_run_created_at
end

#workflow_run_idObject

Returns the value of attribute workflow_run_id.



42
43
44
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 42

def workflow_run_id
  @workflow_run_id
end

#workflow_run_nameObject

Returns the value of attribute workflow_run_name.



38
39
40
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 38

def workflow_run_name
  @workflow_run_name
end

#workflow_run_statusObject

Returns the value of attribute workflow_run_status.



40
41
42
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 40

def workflow_run_status
  @workflow_run_status
end

#workflow_version_idObject

Returns the value of attribute workflow_version_id.



22
23
24
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 22

def workflow_version_id
  @workflow_version_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 451

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 69

def self.attribute_map
  {
    :'metadata' => :'metadata',
    :'tenant_id' => :'tenantId',
    :'workflow_version_id' => :'workflowVersionId',
    :'workflow_id' => :'workflowId',
    :'workflow_name' => :'workflowName',
    :'trigger_at' => :'triggerAt',
    :'method' => :'method',
    :'input' => :'input',
    :'additional_metadata' => :'additionalMetadata',
    :'workflow_run_created_at' => :'workflowRunCreatedAt',
    :'workflow_run_name' => :'workflowRunName',
    :'workflow_run_status' => :'workflowRunStatus',
    :'workflow_run_id' => :'workflowRunId',
    :'priority' => :'priority'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 427

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 99

def self.openapi_types
  {
    :'metadata' => :'APIResourceMeta',
    :'tenant_id' => :'String',
    :'workflow_version_id' => :'String',
    :'workflow_id' => :'String',
    :'workflow_name' => :'String',
    :'trigger_at' => :'Time',
    :'method' => :'ScheduledWorkflowsMethod',
    :'input' => :'Hash<String, Object>',
    :'additional_metadata' => :'Hash<String, Object>',
    :'workflow_run_created_at' => :'Time',
    :'workflow_run_name' => :'String',
    :'workflow_run_status' => :'WorkflowRunStatus',
    :'workflow_run_id' => :'String',
    :'priority' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 393

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      tenant_id == o.tenant_id &&
      workflow_version_id == o.workflow_version_id &&
      workflow_id == o.workflow_id &&
      workflow_name == o.workflow_name &&
      trigger_at == o.trigger_at &&
      method == o.method &&
      input == o.input &&
       == o. &&
      workflow_run_created_at == o.workflow_run_created_at &&
      workflow_run_name == o.workflow_run_name &&
      workflow_run_status == o.workflow_run_status &&
      workflow_run_id == o.workflow_run_id &&
      priority == o.priority
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 522

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


414
415
416
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 414

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



420
421
422
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 420

def hash
  [, tenant_id, workflow_version_id, workflow_id, workflow_name, trigger_at, method, input, , workflow_run_created_at, workflow_run_name, workflow_run_status, workflow_run_id, priority].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 217

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @workflow_version_id.nil?
    invalid_properties.push('invalid value for "workflow_version_id", workflow_version_id cannot be nil.')
  end

  if @workflow_id.nil?
    invalid_properties.push('invalid value for "workflow_id", workflow_id cannot be nil.')
  end

  if @workflow_name.nil?
    invalid_properties.push('invalid value for "workflow_name", workflow_name cannot be nil.')
  end

  if @trigger_at.nil?
    invalid_properties.push('invalid value for "trigger_at", trigger_at cannot be nil.')
  end

  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  if !@workflow_run_id.nil? && @workflow_run_id.to_s.length > 36
    invalid_properties.push('invalid value for "workflow_run_id", the character length must be smaller than or equal to 36.')
  end

  if !@workflow_run_id.nil? && @workflow_run_id.to_s.length < 36
    invalid_properties.push('invalid value for "workflow_run_id", the character length must be greater than or equal to 36.')
  end

  if !@priority.nil? && @priority > 3
    invalid_properties.push('invalid value for "priority", must be smaller than or equal to 3.')
  end

  if !@priority.nil? && @priority < 1
    invalid_properties.push('invalid value for "priority", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



498
499
500
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 498

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 504

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



492
493
494
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 492

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/scheduled_workflows.rb', line 269

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metadata.nil?
  return false if @tenant_id.nil?
  return false if @workflow_version_id.nil?
  return false if @workflow_id.nil?
  return false if @workflow_name.nil?
  return false if @trigger_at.nil?
  return false if @method.nil?
  return false if !@workflow_run_id.nil? && @workflow_run_id.to_s.length > 36
  return false if !@workflow_run_id.nil? && @workflow_run_id.to_s.length < 36
  return false if !@priority.nil? && @priority > 3
  return false if !@priority.nil? && @priority < 1
  true
end