Class: HatchetSdkRest::Tenant
- Inherits:
-
Object
- Object
- HatchetSdkRest::Tenant
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#alert_member_emails ⇒ Object
Whether to alert tenant members.
-
#analytics_opt_out ⇒ Object
Whether the tenant has opted out of analytics.
-
#environment ⇒ Object
The environment type of the tenant.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
The name of the tenant.
-
#region ⇒ Object
Control-plane shard region for the tenant (e.g. aws:us-west-2).
-
#server_url ⇒ Object
The server URL for the tenant (includes scheme).
-
#slug ⇒ Object
The slug of the tenant.
-
#version ⇒ Object
The version of the tenant.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Tenant
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Tenant
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::Tenant` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::Tenant`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'metadata') self. = attributes[:'metadata'] else self. = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'analytics_opt_out') self.analytics_opt_out = attributes[:'analytics_opt_out'] end if attributes.key?(:'alert_member_emails') self.alert_member_emails = attributes[:'alert_member_emails'] end if attributes.key?(:'environment') self.environment = attributes[:'environment'] end if attributes.key?(:'server_url') self.server_url = attributes[:'server_url'] end if attributes.key?(:'region') self.region = attributes[:'region'] end end |
Instance Attribute Details
#alert_member_emails ⇒ Object
Whether to alert tenant members.
33 34 35 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 33 def alert_member_emails @alert_member_emails end |
#analytics_opt_out ⇒ Object
Whether the tenant has opted out of analytics.
30 31 32 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 30 def analytics_opt_out @analytics_opt_out end |
#environment ⇒ Object
The environment type of the tenant.
36 37 38 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 36 def environment @environment end |
#metadata ⇒ Object
Returns the value of attribute metadata.
18 19 20 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 18 def @metadata end |
#name ⇒ Object
The name of the tenant.
21 22 23 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 21 def name @name end |
#region ⇒ Object
Control-plane shard region for the tenant (e.g. aws:us-west-2).
42 43 44 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 42 def region @region end |
#server_url ⇒ Object
The server URL for the tenant (includes scheme)
39 40 41 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 39 def server_url @server_url end |
#slug ⇒ Object
The slug of the tenant.
24 25 26 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 24 def slug @slug end |
#version ⇒ Object
The version of the tenant.
27 28 29 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 27 def version @version end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 303 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = HatchetSdkRest.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 67 def self.attribute_map { :'metadata' => :'metadata', :'name' => :'name', :'slug' => :'slug', :'version' => :'version', :'analytics_opt_out' => :'analyticsOptOut', :'alert_member_emails' => :'alertMemberEmails', :'environment' => :'environment', :'server_url' => :'serverUrl', :'region' => :'region' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 279 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 92 def self.openapi_types { :'metadata' => :'APIResourceMeta', :'name' => :'String', :'slug' => :'String', :'version' => :'TenantVersion', :'analytics_opt_out' => :'Boolean', :'alert_member_emails' => :'Boolean', :'environment' => :'TenantEnvironment', :'server_url' => :'String', :'region' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && name == o.name && slug == o.slug && version == o.version && analytics_opt_out == o.analytics_opt_out && alert_member_emails == o.alert_member_emails && environment == o.environment && server_url == o.server_url && region == o.region end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 374 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
266 267 268 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 266 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
272 273 274 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 272 def hash [, name, slug, version, analytics_opt_out, alert_member_emails, environment, server_url, region].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @metadata.nil? invalid_properties.push('invalid value for "metadata", metadata cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
350 351 352 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 350 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
344 345 346 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 344 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/tenant.rb', line 199 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @metadata.nil? return false if @name.nil? return false if @slug.nil? return false if @version.nil? true end |