Class: HatchetSdkRest::UserApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::UserApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ UserApi
constructor
A new instance of UserApi.
-
#tenant_memberships_list(opts = {}) ⇒ UserTenantMembershipsList
List tenant memberships Lists all tenant memberships for the current user.
-
#tenant_memberships_list_with_http_info(opts = {}) ⇒ Array<(UserTenantMembershipsList, Integer, Hash)>
List tenant memberships Lists all tenant memberships for the current user.
-
#user_create(opts = {}) ⇒ User
Register user Registers a user.
-
#user_create_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Register user Registers a user.
-
#user_get_current(opts = {}) ⇒ User
Get current user Gets the current user.
-
#user_get_current_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Get current user Gets the current user.
-
#user_update_github_oauth_callback(opts = {}) ⇒ nil
Complete OAuth flow Completes the OAuth flow.
-
#user_update_github_oauth_callback_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Complete OAuth flow Completes the OAuth flow.
-
#user_update_github_oauth_start(opts = {}) ⇒ nil
Start OAuth flow Starts the OAuth flow.
-
#user_update_github_oauth_start_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start OAuth flow Starts the OAuth flow.
-
#user_update_google_oauth_callback(opts = {}) ⇒ nil
Complete OAuth flow Completes the OAuth flow.
-
#user_update_google_oauth_callback_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Complete OAuth flow Completes the OAuth flow.
-
#user_update_google_oauth_start(opts = {}) ⇒ nil
Start OAuth flow Starts the OAuth flow.
-
#user_update_google_oauth_start_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start OAuth flow Starts the OAuth flow.
-
#user_update_login(opts = {}) ⇒ User
Login user Logs in a user.
-
#user_update_login_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Login user Logs in a user.
-
#user_update_logout(opts = {}) ⇒ User
Logout user Logs out a user.
-
#user_update_logout_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Logout user Logs out a user.
-
#user_update_password(opts = {}) ⇒ User
Change user password Update a user password.
-
#user_update_password_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Change user password Update a user password.
-
#user_update_slack_oauth_callback(opts = {}) ⇒ nil
Complete OAuth flow Completes the OAuth flow.
-
#user_update_slack_oauth_callback_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Complete OAuth flow Completes the OAuth flow.
-
#user_update_slack_oauth_start(tenant, opts = {}) ⇒ nil
Start OAuth flow Starts the OAuth flow.
-
#user_update_slack_oauth_start_with_http_info(tenant, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start OAuth flow Starts the OAuth flow.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#tenant_memberships_list(opts = {}) ⇒ UserTenantMembershipsList
List tenant memberships Lists all tenant memberships for the current user
26 27 28 29 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 26 def tenant_memberships_list(opts = {}) data, _status_code, _headers = tenant_memberships_list_with_http_info(opts) data end |
#tenant_memberships_list_with_http_info(opts = {}) ⇒ Array<(UserTenantMembershipsList, Integer, Hash)>
List tenant memberships Lists all tenant memberships for the current user
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 35 def tenant_memberships_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.tenant_memberships_list ...' end # resource path local_var_path = '/api/v1/users/memberships' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserTenantMembershipsList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth'] = opts.merge( :operation => :"UserApi.tenant_memberships_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#tenant_memberships_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_create(opts = {}) ⇒ User
Register user Registers a user.
84 85 86 87 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 84 def user_create(opts = {}) data, _status_code, _headers = user_create_with_http_info(opts) data end |
#user_create_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Register user Registers a user.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 94 def user_create_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_create ...' end # resource path local_var_path = '/api/v1/users/register' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'user_register_request']) # return_type return_type = opts[:debug_return_type] || 'User' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.user_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_get_current(opts = {}) ⇒ User
Get current user Gets the current user
147 148 149 150 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 147 def user_get_current(opts = {}) data, _status_code, _headers = user_get_current_with_http_info(opts) data end |
#user_get_current_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Get current user Gets the current user
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 156 def user_get_current_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_get_current ...' end # resource path local_var_path = '/api/v1/users/current' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'User' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth'] = opts.merge( :operation => :"UserApi.user_get_current", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_get_current\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_github_oauth_callback(opts = {}) ⇒ nil
Complete OAuth flow Completes the OAuth flow
204 205 206 207 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 204 def user_update_github_oauth_callback(opts = {}) user_update_github_oauth_callback_with_http_info(opts) nil end |
#user_update_github_oauth_callback_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Complete OAuth flow Completes the OAuth flow
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 213 def user_update_github_oauth_callback_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_github_oauth_callback ...' end # resource path local_var_path = '/api/v1/users/github/callback' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.user_update_github_oauth_callback", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_github_oauth_callback\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_github_oauth_start(opts = {}) ⇒ nil
Start OAuth flow Starts the OAuth flow
259 260 261 262 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 259 def user_update_github_oauth_start(opts = {}) user_update_github_oauth_start_with_http_info(opts) nil end |
#user_update_github_oauth_start_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start OAuth flow Starts the OAuth flow
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 268 def user_update_github_oauth_start_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_github_oauth_start ...' end # resource path local_var_path = '/api/v1/users/github/start' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.user_update_github_oauth_start", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_github_oauth_start\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_google_oauth_callback(opts = {}) ⇒ nil
Complete OAuth flow Completes the OAuth flow
314 315 316 317 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 314 def user_update_google_oauth_callback(opts = {}) user_update_google_oauth_callback_with_http_info(opts) nil end |
#user_update_google_oauth_callback_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Complete OAuth flow Completes the OAuth flow
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 323 def user_update_google_oauth_callback_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_google_oauth_callback ...' end # resource path local_var_path = '/api/v1/users/google/callback' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.user_update_google_oauth_callback", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_google_oauth_callback\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_google_oauth_start(opts = {}) ⇒ nil
Start OAuth flow Starts the OAuth flow
369 370 371 372 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 369 def user_update_google_oauth_start(opts = {}) user_update_google_oauth_start_with_http_info(opts) nil end |
#user_update_google_oauth_start_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start OAuth flow Starts the OAuth flow
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 378 def user_update_google_oauth_start_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_google_oauth_start ...' end # resource path local_var_path = '/api/v1/users/google/start' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.user_update_google_oauth_start", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_google_oauth_start\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_login(opts = {}) ⇒ User
Login user Logs in a user.
425 426 427 428 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 425 def user_update_login(opts = {}) data, _status_code, _headers = user_update_login_with_http_info(opts) data end |
#user_update_login_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Login user Logs in a user.
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 435 def user_update_login_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_login ...' end # resource path local_var_path = '/api/v1/users/login' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'user_login_request']) # return_type return_type = opts[:debug_return_type] || 'User' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.user_update_login", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_logout(opts = {}) ⇒ User
Logout user Logs out a user.
488 489 490 491 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 488 def user_update_logout(opts = {}) data, _status_code, _headers = user_update_logout_with_http_info(opts) data end |
#user_update_logout_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Logout user Logs out a user.
497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 497 def user_update_logout_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_logout ...' end # resource path local_var_path = '/api/v1/users/logout' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'User' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth'] = opts.merge( :operation => :"UserApi.user_update_logout", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_logout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_password(opts = {}) ⇒ User
Change user password Update a user password.
546 547 548 549 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 546 def user_update_password(opts = {}) data, _status_code, _headers = user_update_password_with_http_info(opts) data end |
#user_update_password_with_http_info(opts = {}) ⇒ Array<(User, Integer, Hash)>
Change user password Update a user password.
556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 556 def user_update_password_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_password ...' end # resource path local_var_path = '/api/v1/users/password' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'user_change_password_request']) # return_type return_type = opts[:debug_return_type] || 'User' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth'] = opts.merge( :operation => :"UserApi.user_update_password", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_password\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_slack_oauth_callback(opts = {}) ⇒ nil
Complete OAuth flow Completes the OAuth flow
609 610 611 612 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 609 def user_update_slack_oauth_callback(opts = {}) user_update_slack_oauth_callback_with_http_info(opts) nil end |
#user_update_slack_oauth_callback_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Complete OAuth flow Completes the OAuth flow
618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 618 def user_update_slack_oauth_callback_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_slack_oauth_callback ...' end # resource path local_var_path = '/api/v1/users/slack/callback' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth'] = opts.merge( :operation => :"UserApi.user_update_slack_oauth_callback", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_slack_oauth_callback\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#user_update_slack_oauth_start(tenant, opts = {}) ⇒ nil
Start OAuth flow Starts the OAuth flow
665 666 667 668 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 665 def user_update_slack_oauth_start(tenant, opts = {}) user_update_slack_oauth_start_with_http_info(tenant, opts) nil end |
#user_update_slack_oauth_start_with_http_info(tenant, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start OAuth flow Starts the OAuth flow
675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/user_api.rb', line 675 def user_update_slack_oauth_start_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.user_update_slack_oauth_start ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling UserApi.user_update_slack_oauth_start" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling UserApi.user_update_slack_oauth_start, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling UserApi.user_update_slack_oauth_start, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/slack/start'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth'] = opts.merge( :operation => :"UserApi.user_update_slack_oauth_start", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#user_update_slack_oauth_start\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |