Class: HatchetSdkRest::V1DurableEventLogEntry

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1DurableEventLogEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::V1DurableEventLogEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::V1DurableEventLogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'node_id')
    self.node_id = attributes[:'node_id']
  else
    self.node_id = nil
  end

  if attributes.key?(:'branch_id')
    self.branch_id = attributes[:'branch_id']
  else
    self.branch_id = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'is_satisfied')
    self.is_satisfied = attributes[:'is_satisfied']
  else
    self.is_satisfied = nil
  end

  if attributes.key?(:'inserted_at')
    self.inserted_at = attributes[:'inserted_at']
  else
    self.inserted_at = nil
  end

  if attributes.key?(:'task_external_id')
    self.task_external_id = attributes[:'task_external_id']
  else
    self.task_external_id = nil
  end

  if attributes.key?(:'task_display_name')
    self.task_display_name = attributes[:'task_display_name']
  else
    self.task_display_name = nil
  end

  if attributes.key?(:'wait_data')
    if (value = attributes[:'wait_data']).is_a?(Array)
      self.wait_data = value
    end
  end

  if attributes.key?(:'satisfied_at')
    self.satisfied_at = attributes[:'satisfied_at']
  end

  if attributes.key?(:'user_message')
    self.user_message = attributes[:'user_message']
  end
end

Instance Attribute Details

#branch_idObject

The branch id when this entry was first seen.



22
23
24
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 22

def branch_id
  @branch_id
end

#inserted_atObject

When this entry was inserted.



30
31
32
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 30

def inserted_at
  @inserted_at
end

#is_satisfiedObject

Whether this entry has been satisfied.



27
28
29
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 27

def is_satisfied
  @is_satisfied
end

#kindObject

Returns the value of attribute kind.



24
25
26
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 24

def kind
  @kind
end

#node_idObject

The monotonically increasing node id in the event log.



19
20
21
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 19

def node_id
  @node_id
end

#satisfied_atObject

When this entry was satisfied, if it has been satisfied.



41
42
43
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 41

def satisfied_at
  @satisfied_at
end

#task_display_nameObject

The display name of the durable task this event log entry is associated with.



36
37
38
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 36

def task_display_name
  @task_display_name
end

#task_external_idObject

The external id of the durable task this event log entry is associated with.



33
34
35
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 33

def task_external_id
  @task_external_id
end

#user_messageObject

A user-provided message or label, sent when establishing a durable wait.



44
45
46
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 44

def user_message
  @user_message
end

#wait_dataObject

Returns the value of attribute wait_data.



38
39
40
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 38

def wait_data
  @wait_data
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 383

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 69

def self.attribute_map
  {
    :'node_id' => :'nodeId',
    :'branch_id' => :'branchId',
    :'kind' => :'kind',
    :'is_satisfied' => :'isSatisfied',
    :'inserted_at' => :'insertedAt',
    :'task_external_id' => :'taskExternalId',
    :'task_display_name' => :'taskDisplayName',
    :'wait_data' => :'waitData',
    :'satisfied_at' => :'satisfiedAt',
    :'user_message' => :'userMessage'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 359

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 95

def self.openapi_types
  {
    :'node_id' => :'Integer',
    :'branch_id' => :'Integer',
    :'kind' => :'V1DurableEventLogKind',
    :'is_satisfied' => :'Boolean',
    :'inserted_at' => :'Time',
    :'task_external_id' => :'String',
    :'task_display_name' => :'String',
    :'wait_data' => :'Array<V1WaitItem>',
    :'satisfied_at' => :'Time',
    :'user_message' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 329

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      node_id == o.node_id &&
      branch_id == o.branch_id &&
      kind == o.kind &&
      is_satisfied == o.is_satisfied &&
      inserted_at == o.inserted_at &&
      task_external_id == o.task_external_id &&
      task_display_name == o.task_display_name &&
      wait_data == o.wait_data &&
      satisfied_at == o.satisfied_at &&
      user_message == o.user_message
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 454

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


346
347
348
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 346

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



352
353
354
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 352

def hash
  [node_id, branch_id, kind, is_satisfied, inserted_at, task_external_id, task_display_name, wait_data, satisfied_at, user_message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @node_id.nil?
    invalid_properties.push('invalid value for "node_id", node_id cannot be nil.')
  end

  if @branch_id.nil?
    invalid_properties.push('invalid value for "branch_id", branch_id cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @is_satisfied.nil?
    invalid_properties.push('invalid value for "is_satisfied", is_satisfied cannot be nil.')
  end

  if @inserted_at.nil?
    invalid_properties.push('invalid value for "inserted_at", inserted_at cannot be nil.')
  end

  if @task_external_id.nil?
    invalid_properties.push('invalid value for "task_external_id", task_external_id cannot be nil.')
  end

  if @task_external_id.to_s.length > 36
    invalid_properties.push('invalid value for "task_external_id", the character length must be smaller than or equal to 36.')
  end

  if @task_external_id.to_s.length < 36
    invalid_properties.push('invalid value for "task_external_id", the character length must be greater than or equal to 36.')
  end

  if @task_display_name.nil?
    invalid_properties.push('invalid value for "task_display_name", task_display_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 430

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



424
425
426
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 424

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_durable_event_log_entry.rb', line 235

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @node_id.nil?
  return false if @branch_id.nil?
  return false if @kind.nil?
  return false if @is_satisfied.nil?
  return false if @inserted_at.nil?
  return false if @task_external_id.nil?
  return false if @task_external_id.to_s.length > 36
  return false if @task_external_id.to_s.length < 36
  return false if @task_display_name.nil?
  true
end