Class: HatchetSdkRest::V1Event

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1Event

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::V1Event` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::V1Event`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'workflow_run_summary')
    self.workflow_run_summary = attributes[:'workflow_run_summary']
  else
    self.workflow_run_summary = nil
  end

  if attributes.key?(:'tenant')
    self.tenant = attributes[:'tenant']
  end

  if attributes.key?(:'additional_metadata')
    self. = attributes[:'additional_metadata']
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'seen_at')
    self.seen_at = attributes[:'seen_at']
  end

  if attributes.key?(:'triggered_runs')
    if (value = attributes[:'triggered_runs']).is_a?(Array)
      self.triggered_runs = value
    end
  end

  if attributes.key?(:'triggering_webhook_name')
    self.triggering_webhook_name = attributes[:'triggering_webhook_name']
  end

  if attributes.key?(:'payloads_restricted')
    self.payloads_restricted = attributes[:'payloads_restricted']
  end
end

Instance Attribute Details

#additional_metadataObject

Additional metadata for the event.



33
34
35
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 33

def 
  @additional_metadata
end

#keyObject

The key for the event.



21
22
23
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 21

def key
  @key
end

#metadataObject

Returns the value of attribute metadata.



18
19
20
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 18

def 
  @metadata
end

#payloadObject

The payload of the event, which can be any JSON-serializable object.



36
37
38
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 36

def payload
  @payload
end

#payloads_restrictedObject

True when the event payload was omitted because the caller cannot view payloads. Additional metadata is still included.



51
52
53
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 51

def payloads_restricted
  @payloads_restricted
end

#scopeObject

The scope of the event, which can be used to filter or categorize events.



39
40
41
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 39

def scope
  @scope
end

#seen_atObject

The timestamp when the event was seen.



42
43
44
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 42

def seen_at
  @seen_at
end

#tenantObject

The tenant associated with this event.



30
31
32
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 30

def tenant
  @tenant
end

#tenant_idObject

The ID of the tenant associated with this event.



24
25
26
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 24

def tenant_id
  @tenant_id
end

#triggered_runsObject

The external IDs of the runs that were triggered by this event.



45
46
47
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 45

def triggered_runs
  @triggered_runs
end

#triggering_webhook_nameObject

The name of the webhook that triggered this event, if applicable.



48
49
50
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 48

def triggering_webhook_name
  @triggering_webhook_name
end

#workflow_run_summaryObject

The workflow run summary for this event.



27
28
29
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 27

def workflow_run_summary
  @workflow_run_summary
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 313

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 54

def self.attribute_map
  {
    :'metadata' => :'metadata',
    :'key' => :'key',
    :'tenant_id' => :'tenantId',
    :'workflow_run_summary' => :'workflowRunSummary',
    :'tenant' => :'tenant',
    :'additional_metadata' => :'additionalMetadata',
    :'payload' => :'payload',
    :'scope' => :'scope',
    :'seen_at' => :'seenAt',
    :'triggered_runs' => :'triggeredRuns',
    :'triggering_webhook_name' => :'triggeringWebhookName',
    :'payloads_restricted' => :'payloadsRestricted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 289

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 82

def self.openapi_types
  {
    :'metadata' => :'APIResourceMeta',
    :'key' => :'String',
    :'tenant_id' => :'String',
    :'workflow_run_summary' => :'V1EventWorkflowRunSummary',
    :'tenant' => :'Tenant',
    :'additional_metadata' => :'Object',
    :'payload' => :'Object',
    :'scope' => :'String',
    :'seen_at' => :'Time',
    :'triggered_runs' => :'Array<V1EventTriggeredRun>',
    :'triggering_webhook_name' => :'String',
    :'payloads_restricted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      key == o.key &&
      tenant_id == o.tenant_id &&
      workflow_run_summary == o.workflow_run_summary &&
      tenant == o.tenant &&
       == o. &&
      payload == o.payload &&
      scope == o.scope &&
      seen_at == o.seen_at &&
      triggered_runs == o.triggered_runs &&
      triggering_webhook_name == o.triggering_webhook_name &&
      payloads_restricted == o.payloads_restricted
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 384

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


276
277
278
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 276

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



282
283
284
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 282

def hash
  [, key, tenant_id, workflow_run_summary, tenant, , payload, scope, seen_at, triggered_runs, triggering_webhook_name, payloads_restricted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 182

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @workflow_run_summary.nil?
    invalid_properties.push('invalid value for "workflow_run_summary", workflow_run_summary cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 360

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



354
355
356
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 354

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_event.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metadata.nil?
  return false if @key.nil?
  return false if @tenant_id.nil?
  return false if @workflow_run_summary.nil?
  true
end