Class: HatchetSdkRest::V1HTTPOperator

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1HTTPOperator

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::V1HTTPOperator` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::V1HTTPOperator`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'trigger_endpoint')
    self.trigger_endpoint = attributes[:'trigger_endpoint']
  else
    self.trigger_endpoint = nil
  end

  if attributes.key?(:'healthcheck_endpoint')
    self.healthcheck_endpoint = attributes[:'healthcheck_endpoint']
  else
    self.healthcheck_endpoint = nil
  end

  if attributes.key?(:'request_timeout_seconds')
    self.request_timeout_seconds = attributes[:'request_timeout_seconds']
  else
    self.request_timeout_seconds = nil
  end
end

Instance Attribute Details

#healthcheck_endpointObject

The HTTPS endpoint polled periodically to discover the actions this operator handles.



30
31
32
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 30

def healthcheck_endpoint
  @healthcheck_endpoint
end

#metadataObject

Returns the value of attribute metadata.



18
19
20
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 18

def 
  @metadata
end

#nameObject

The name of the operator.



24
25
26
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 24

def name
  @name
end

#request_timeout_secondsObject

The per-request timeout backstop, in seconds.



33
34
35
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 33

def request_timeout_seconds
  @request_timeout_seconds
end

#tenant_idObject

The ID of the tenant associated with this operator.



21
22
23
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 21

def tenant_id
  @tenant_id
end

#trigger_endpointObject

The HTTPS endpoint (https, port 443) that assigned tasks are delivered to.



27
28
29
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 27

def trigger_endpoint
  @trigger_endpoint
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 285

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 36

def self.attribute_map
  {
    :'metadata' => :'metadata',
    :'tenant_id' => :'tenantId',
    :'name' => :'name',
    :'trigger_endpoint' => :'triggerEndpoint',
    :'healthcheck_endpoint' => :'healthcheckEndpoint',
    :'request_timeout_seconds' => :'requestTimeoutSeconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 261

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 58

def self.openapi_types
  {
    :'metadata' => :'APIResourceMeta',
    :'tenant_id' => :'String',
    :'name' => :'String',
    :'trigger_endpoint' => :'String',
    :'healthcheck_endpoint' => :'String',
    :'request_timeout_seconds' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      tenant_id == o.tenant_id &&
      name == o.name &&
      trigger_endpoint == o.trigger_endpoint &&
      healthcheck_endpoint == o.healthcheck_endpoint &&
      request_timeout_seconds == o.request_timeout_seconds
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 356

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


248
249
250
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 248

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



254
255
256
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 254

def hash
  [, tenant_id, name, trigger_endpoint, healthcheck_endpoint, request_timeout_seconds].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @trigger_endpoint.nil?
    invalid_properties.push('invalid value for "trigger_endpoint", trigger_endpoint cannot be nil.')
  end

  if @healthcheck_endpoint.nil?
    invalid_properties.push('invalid value for "healthcheck_endpoint", healthcheck_endpoint cannot be nil.')
  end

  if @request_timeout_seconds.nil?
    invalid_properties.push('invalid value for "request_timeout_seconds", request_timeout_seconds cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 332

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 338

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



326
327
328
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 326

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
170
171
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_http_operator.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metadata.nil?
  return false if @tenant_id.nil?
  return false if @name.nil?
  return false if @trigger_endpoint.nil?
  return false if @healthcheck_endpoint.nil?
  return false if @request_timeout_seconds.nil?
  true
end