Class: HatchetSdkRest::V1TaskTiming

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1TaskTiming

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 148

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::V1TaskTiming` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::V1TaskTiming`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'depth')
    self.depth = attributes[:'depth']
  else
    self.depth = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'task_display_name')
    self.task_display_name = attributes[:'task_display_name']
  else
    self.task_display_name = nil
  end

  if attributes.key?(:'task_external_id')
    self.task_external_id = attributes[:'task_external_id']
  else
    self.task_external_id = nil
  end

  if attributes.key?(:'task_id')
    self.task_id = attributes[:'task_id']
  else
    self.task_id = nil
  end

  if attributes.key?(:'task_inserted_at')
    self.task_inserted_at = attributes[:'task_inserted_at']
  else
    self.task_inserted_at = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'is_evicted')
    self.is_evicted = attributes[:'is_evicted']
  end

  if attributes.key?(:'parent_task_external_id')
    self.parent_task_external_id = attributes[:'parent_task_external_id']
  end

  if attributes.key?(:'queued_at')
    self.queued_at = attributes[:'queued_at']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'finished_at')
    self.finished_at = attributes[:'finished_at']
  end

  if attributes.key?(:'workflow_run_id')
    self.workflow_run_id = attributes[:'workflow_run_id']
  end

  if attributes.key?(:'retry_count')
    self.retry_count = attributes[:'retry_count']
  end

  if attributes.key?(:'attempt')
    self.attempt = attributes[:'attempt']
  end
end

Instance Attribute Details

#attemptObject

The attempt number of the task.



62
63
64
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 62

def attempt
  @attempt
end

#depthObject

The depth of the task in the waterfall.



21
22
23
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 21

def depth
  @depth
end

#finished_atObject

The timestamp the task run finished.



53
54
55
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 53

def finished_at
  @finished_at
end

#is_evictedObject

Whether the task has been evicted from a worker (still counts as RUNNING).



41
42
43
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 41

def is_evicted
  @is_evicted
end

#metadataObject

Returns the value of attribute metadata.



18
19
20
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 18

def 
  @metadata
end

#parent_task_external_idObject

The external ID of the parent task.



44
45
46
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 44

def parent_task_external_id
  @parent_task_external_id
end

#queued_atObject

The timestamp the task run was queued.



47
48
49
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 47

def queued_at
  @queued_at
end

#retry_countObject

The number of retries of the task.



59
60
61
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 59

def retry_count
  @retry_count
end

#started_atObject

The timestamp the task run started.



50
51
52
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 50

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 23

def status
  @status
end

#task_display_nameObject

The display name of the task run.



26
27
28
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 26

def task_display_name
  @task_display_name
end

#task_external_idObject

The external ID of the task.



29
30
31
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 29

def task_external_id
  @task_external_id
end

#task_idObject

The ID of the task.



32
33
34
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 32

def task_id
  @task_id
end

#task_inserted_atObject

The timestamp the task was inserted.



35
36
37
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 35

def task_inserted_at
  @task_inserted_at
end

#tenant_idObject

The ID of the tenant.



38
39
40
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 38

def tenant_id
  @tenant_id
end

#workflow_run_idObject

The external ID of the workflow run.



56
57
58
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 56

def workflow_run_id
  @workflow_run_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 504

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



109
110
111
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 109

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 114

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 87

def self.attribute_map
  {
    :'metadata' => :'metadata',
    :'depth' => :'depth',
    :'status' => :'status',
    :'task_display_name' => :'taskDisplayName',
    :'task_external_id' => :'taskExternalId',
    :'task_id' => :'taskId',
    :'task_inserted_at' => :'taskInsertedAt',
    :'tenant_id' => :'tenantId',
    :'is_evicted' => :'isEvicted',
    :'parent_task_external_id' => :'parentTaskExternalId',
    :'queued_at' => :'queuedAt',
    :'started_at' => :'startedAt',
    :'finished_at' => :'finishedAt',
    :'workflow_run_id' => :'workflowRunId',
    :'retry_count' => :'retryCount',
    :'attempt' => :'attempt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 480

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



141
142
143
144
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 141

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 119

def self.openapi_types
  {
    :'metadata' => :'APIResourceMeta',
    :'depth' => :'Integer',
    :'status' => :'V1TaskStatus',
    :'task_display_name' => :'String',
    :'task_external_id' => :'String',
    :'task_id' => :'Integer',
    :'task_inserted_at' => :'Time',
    :'tenant_id' => :'String',
    :'is_evicted' => :'Boolean',
    :'parent_task_external_id' => :'String',
    :'queued_at' => :'Time',
    :'started_at' => :'Time',
    :'finished_at' => :'Time',
    :'workflow_run_id' => :'String',
    :'retry_count' => :'Integer',
    :'attempt' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 444

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      depth == o.depth &&
      status == o.status &&
      task_display_name == o.task_display_name &&
      task_external_id == o.task_external_id &&
      task_id == o.task_id &&
      task_inserted_at == o.task_inserted_at &&
      tenant_id == o.tenant_id &&
      is_evicted == o.is_evicted &&
      parent_task_external_id == o.parent_task_external_id &&
      queued_at == o.queued_at &&
      started_at == o.started_at &&
      finished_at == o.finished_at &&
      workflow_run_id == o.workflow_run_id &&
      retry_count == o.retry_count &&
      attempt == o.attempt
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 575

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


467
468
469
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 467

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



473
474
475
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 473

def hash
  [, depth, status, task_display_name, task_external_id, task_id, task_inserted_at, tenant_id, is_evicted, parent_task_external_id, queued_at, started_at, finished_at, workflow_run_id, retry_count, attempt].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 245

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @depth.nil?
    invalid_properties.push('invalid value for "depth", depth cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @task_display_name.nil?
    invalid_properties.push('invalid value for "task_display_name", task_display_name cannot be nil.')
  end

  if @task_external_id.nil?
    invalid_properties.push('invalid value for "task_external_id", task_external_id cannot be nil.')
  end

  if @task_external_id.to_s.length > 36
    invalid_properties.push('invalid value for "task_external_id", the character length must be smaller than or equal to 36.')
  end

  if @task_external_id.to_s.length < 36
    invalid_properties.push('invalid value for "task_external_id", the character length must be greater than or equal to 36.')
  end

  if @task_id.nil?
    invalid_properties.push('invalid value for "task_id", task_id cannot be nil.')
  end

  if @task_inserted_at.nil?
    invalid_properties.push('invalid value for "task_inserted_at", task_inserted_at cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @tenant_id.to_s.length > 36
    invalid_properties.push('invalid value for "tenant_id", the character length must be smaller than or equal to 36.')
  end

  if @tenant_id.to_s.length < 36
    invalid_properties.push('invalid value for "tenant_id", the character length must be greater than or equal to 36.')
  end

  if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length > 36
    invalid_properties.push('invalid value for "parent_task_external_id", the character length must be smaller than or equal to 36.')
  end

  if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length < 36
    invalid_properties.push('invalid value for "parent_task_external_id", the character length must be greater than or equal to 36.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



551
552
553
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 551

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 557

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



545
546
547
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 545

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_task_timing.rb', line 309

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metadata.nil?
  return false if @depth.nil?
  return false if @status.nil?
  return false if @task_display_name.nil?
  return false if @task_external_id.nil?
  return false if @task_external_id.to_s.length > 36
  return false if @task_external_id.to_s.length < 36
  return false if @task_id.nil?
  return false if @task_inserted_at.nil?
  return false if @tenant_id.nil?
  return false if @tenant_id.to_s.length > 36
  return false if @tenant_id.to_s.length < 36
  return false if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length > 36
  return false if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length < 36
  true
end