Class: HatchetSdkRest::V1WorkflowRun
- Inherits:
-
Object
- Object
- HatchetSdkRest::V1WorkflowRun
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#additional_metadata ⇒ Object
Additional metadata for the task run.
-
#created_at ⇒ Object
The timestamp the task run was created.
-
#display_name ⇒ Object
The display name of the task run.
-
#duration ⇒ Object
The duration of the task run, in milliseconds.
-
#error_message ⇒ Object
The error message of the task run (for the latest run).
-
#finished_at ⇒ Object
The timestamp the task run finished.
-
#input ⇒ Object
The input of the task run.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#output ⇒ Object
The output of the task run (for the latest run).
-
#parent_task_external_id ⇒ Object
Returns the value of attribute parent_task_external_id.
-
#started_at ⇒ Object
The timestamp the task run started.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tenant_id ⇒ Object
The ID of the tenant.
-
#workflow_id ⇒ Object
Returns the value of attribute workflow_id.
-
#workflow_version_id ⇒ Object
The ID of the workflow version.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1WorkflowRun
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1WorkflowRun
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::V1WorkflowRun` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::V1WorkflowRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'metadata') self. = attributes[:'metadata'] else self. = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] else self.display_name = nil end if attributes.key?(:'workflow_id') self.workflow_id = attributes[:'workflow_id'] else self.workflow_id = nil end if attributes.key?(:'output') self.output = attributes[:'output'] else self.output = nil end if attributes.key?(:'input') self.input = attributes[:'input'] else self.input = nil end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'finished_at') self.finished_at = attributes[:'finished_at'] end if attributes.key?(:'duration') self.duration = attributes[:'duration'] end if attributes.key?(:'additional_metadata') self. = attributes[:'additional_metadata'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'workflow_version_id') self.workflow_version_id = attributes[:'workflow_version_id'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'parent_task_external_id') self.parent_task_external_id = attributes[:'parent_task_external_id'] end end |
Instance Attribute Details
#additional_metadata ⇒ Object
Additional metadata for the task run.
46 47 48 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 46 def @additional_metadata end |
#created_at ⇒ Object
The timestamp the task run was created.
55 56 57 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 55 def created_at @created_at end |
#display_name ⇒ Object
The display name of the task run.
26 27 28 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 26 def display_name @display_name end |
#duration ⇒ Object
The duration of the task run, in milliseconds.
43 44 45 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 43 def duration @duration end |
#error_message ⇒ Object
The error message of the task run (for the latest run)
49 50 51 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 49 def @error_message end |
#finished_at ⇒ Object
The timestamp the task run finished.
40 41 42 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 40 def finished_at @finished_at end |
#input ⇒ Object
The input of the task run.
34 35 36 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 34 def input @input end |
#metadata ⇒ Object
Returns the value of attribute metadata.
18 19 20 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 18 def @metadata end |
#output ⇒ Object
The output of the task run (for the latest run)
31 32 33 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 31 def output @output end |
#parent_task_external_id ⇒ Object
Returns the value of attribute parent_task_external_id.
57 58 59 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 57 def parent_task_external_id @parent_task_external_id end |
#started_at ⇒ Object
The timestamp the task run started.
37 38 39 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 37 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 20 def status @status end |
#tenant_id ⇒ Object
The ID of the tenant.
23 24 25 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 23 def tenant_id @tenant_id end |
#workflow_id ⇒ Object
Returns the value of attribute workflow_id.
28 29 30 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 28 def workflow_id @workflow_id end |
#workflow_version_id ⇒ Object
The ID of the workflow version.
52 53 54 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 52 def workflow_version_id @workflow_version_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 457 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = HatchetSdkRest.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
103 104 105 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 103 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
108 109 110 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 108 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 82 def self.attribute_map { :'metadata' => :'metadata', :'status' => :'status', :'tenant_id' => :'tenantId', :'display_name' => :'displayName', :'workflow_id' => :'workflowId', :'output' => :'output', :'input' => :'input', :'started_at' => :'startedAt', :'finished_at' => :'finishedAt', :'duration' => :'duration', :'additional_metadata' => :'additionalMetadata', :'error_message' => :'errorMessage', :'workflow_version_id' => :'workflowVersionId', :'created_at' => :'createdAt', :'parent_task_external_id' => :'parentTaskExternalId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 433 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
134 135 136 137 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 134 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 113 def self.openapi_types { :'metadata' => :'APIResourceMeta', :'status' => :'V1TaskStatus', :'tenant_id' => :'String', :'display_name' => :'String', :'workflow_id' => :'String', :'output' => :'Object', :'input' => :'Object', :'started_at' => :'Time', :'finished_at' => :'Time', :'duration' => :'Integer', :'additional_metadata' => :'Object', :'error_message' => :'String', :'workflow_version_id' => :'String', :'created_at' => :'Time', :'parent_task_external_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 398 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && status == o.status && tenant_id == o.tenant_id && display_name == o.display_name && workflow_id == o.workflow_id && output == o.output && input == o.input && started_at == o.started_at && finished_at == o.finished_at && duration == o.duration && == o. && == o. && workflow_version_id == o.workflow_version_id && created_at == o.created_at && parent_task_external_id == o.parent_task_external_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 528 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
420 421 422 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 420 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
426 427 428 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 426 def hash [, status, tenant_id, display_name, workflow_id, output, input, started_at, finished_at, duration, , , workflow_version_id, created_at, parent_task_external_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 232 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @metadata.nil? invalid_properties.push('invalid value for "metadata", metadata cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @tenant_id.to_s.length > 36 invalid_properties.push('invalid value for "tenant_id", the character length must be smaller than or equal to 36.') end if @tenant_id.to_s.length < 36 invalid_properties.push('invalid value for "tenant_id", the character length must be greater than or equal to 36.') end if @display_name.nil? invalid_properties.push('invalid value for "display_name", display_name cannot be nil.') end if @workflow_id.nil? invalid_properties.push('invalid value for "workflow_id", workflow_id cannot be nil.') end if @output.nil? invalid_properties.push('invalid value for "output", output cannot be nil.') end if @input.nil? invalid_properties.push('invalid value for "input", input cannot be nil.') end if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length > 36 invalid_properties.push('invalid value for "parent_task_external_id", the character length must be smaller than or equal to 36.') end if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length < 36 invalid_properties.push('invalid value for "parent_task_external_id", the character length must be greater than or equal to 36.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
504 505 506 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 504 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
510 511 512 513 514 515 516 517 518 519 520 521 522 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 510 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
498 499 500 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 498 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/v1_workflow_run.rb', line 284 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @metadata.nil? return false if @status.nil? return false if @tenant_id.nil? return false if @tenant_id.to_s.length > 36 return false if @tenant_id.to_s.length < 36 return false if @display_name.nil? return false if @workflow_id.nil? return false if @output.nil? return false if @input.nil? return false if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length > 36 return false if !@parent_task_external_id.nil? && @parent_task_external_id.to_s.length < 36 true end |