Class: HatchetSdkRest::WorkerApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::WorkerApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ WorkerApi
constructor
A new instance of WorkerApi.
-
#worker_get(worker, opts = {}) ⇒ Worker
Get worker Get a worker.
-
#worker_get_with_http_info(worker, opts = {}) ⇒ Array<(Worker, Integer, Hash)>
Get worker Get a worker.
-
#worker_list(tenant, opts = {}) ⇒ WorkerList
Get workers Get all workers for a tenant.
-
#worker_list_with_http_info(tenant, opts = {}) ⇒ Array<(WorkerList, Integer, Hash)>
Get workers Get all workers for a tenant.
-
#worker_update(worker, update_worker_request, opts = {}) ⇒ Worker
Update worker Update a worker.
-
#worker_update_with_http_info(worker, update_worker_request, opts = {}) ⇒ Array<(Worker, Integer, Hash)>
Update worker Update a worker.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#worker_get(worker, opts = {}) ⇒ Worker
Get worker Get a worker
27 28 29 30 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb', line 27 def worker_get(worker, opts = {}) data, _status_code, _headers = worker_get_with_http_info(worker, opts) data end |
#worker_get_with_http_info(worker, opts = {}) ⇒ Array<(Worker, Integer, Hash)>
Get worker Get a worker
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb', line 37 def worker_get_with_http_info(worker, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkerApi.worker_get ...' end # verify the required parameter 'worker' is set if @api_client.config.client_side_validation && worker.nil? fail ArgumentError, "Missing the required parameter 'worker' when calling WorkerApi.worker_get" end if @api_client.config.client_side_validation && worker.to_s.length > 36 fail ArgumentError, 'invalid value for "worker" when calling WorkerApi.worker_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && worker.to_s.length < 36 fail ArgumentError, 'invalid value for "worker" when calling WorkerApi.worker_get, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/workers/{worker}'.sub('{' + 'worker' + '}', CGI.escape(worker.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Worker' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkerApi.worker_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkerApi#worker_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#worker_list(tenant, opts = {}) ⇒ WorkerList
Get workers Get all workers for a tenant
98 99 100 101 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb', line 98 def worker_list(tenant, opts = {}) data, _status_code, _headers = worker_list_with_http_info(tenant, opts) data end |
#worker_list_with_http_info(tenant, opts = {}) ⇒ Array<(WorkerList, Integer, Hash)>
Get workers Get all workers for a tenant
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb', line 108 def worker_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkerApi.worker_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkerApi.worker_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkerApi.worker_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkerApi.worker_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/worker'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WorkerList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkerApi.worker_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkerApi#worker_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#worker_update(worker, update_worker_request, opts = {}) ⇒ Worker
Update worker Update a worker
170 171 172 173 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb', line 170 def worker_update(worker, update_worker_request, opts = {}) data, _status_code, _headers = worker_update_with_http_info(worker, update_worker_request, opts) data end |
#worker_update_with_http_info(worker, update_worker_request, opts = {}) ⇒ Array<(Worker, Integer, Hash)>
Update worker Update a worker
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/worker_api.rb', line 181 def worker_update_with_http_info(worker, update_worker_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkerApi.worker_update ...' end # verify the required parameter 'worker' is set if @api_client.config.client_side_validation && worker.nil? fail ArgumentError, "Missing the required parameter 'worker' when calling WorkerApi.worker_update" end if @api_client.config.client_side_validation && worker.to_s.length > 36 fail ArgumentError, 'invalid value for "worker" when calling WorkerApi.worker_update, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && worker.to_s.length < 36 fail ArgumentError, 'invalid value for "worker" when calling WorkerApi.worker_update, the character length must be greater than or equal to 36.' end # verify the required parameter 'update_worker_request' is set if @api_client.config.client_side_validation && update_worker_request.nil? fail ArgumentError, "Missing the required parameter 'update_worker_request' when calling WorkerApi.worker_update" end # resource path local_var_path = '/api/v1/workers/{worker}'.sub('{' + 'worker' + '}', CGI.escape(worker.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_worker_request) # return_type return_type = opts[:debug_return_type] || 'Worker' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkerApi.worker_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkerApi#worker_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |