Class: HatchetSdkRest::WorkflowRun

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkflowRun

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::WorkflowRun` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::WorkflowRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'workflow_version_id')
    self.workflow_version_id = attributes[:'workflow_version_id']
  else
    self.workflow_version_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'triggered_by')
    self.triggered_by = attributes[:'triggered_by']
  else
    self.triggered_by = nil
  end

  if attributes.key?(:'workflow_version')
    self.workflow_version = attributes[:'workflow_version']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'job_runs')
    if (value = attributes[:'job_runs']).is_a?(Array)
      self.job_runs = value
    end
  end

  if attributes.key?(:'input')
    if (value = attributes[:'input']).is_a?(Hash)
      self.input = value
    end
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'finished_at')
    self.finished_at = attributes[:'finished_at']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'parent_step_run_id')
    self.parent_step_run_id = attributes[:'parent_step_run_id']
  end

  if attributes.key?(:'additional_metadata')
    if (value = attributes[:'additional_metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#additional_metadataObject

Returns the value of attribute additional_metadata.



48
49
50
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 48

def 
  @additional_metadata
end

#display_nameObject

Returns the value of attribute display_name.



30
31
32
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 30

def display_name
  @display_name
end

#durationObject

Returns the value of attribute duration.



42
43
44
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 42

def duration
  @duration
end

#errorObject

Returns the value of attribute error.



36
37
38
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 36

def error
  @error
end

#finished_atObject

Returns the value of attribute finished_at.



40
41
42
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 40

def finished_at
  @finished_at
end

#inputObject

Returns the value of attribute input.



34
35
36
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 34

def input
  @input
end

#job_runsObject

Returns the value of attribute job_runs.



32
33
34
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 32

def job_runs
  @job_runs
end

#metadataObject

Returns the value of attribute metadata.



18
19
20
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 18

def 
  @metadata
end

#parent_idObject

Returns the value of attribute parent_id.



44
45
46
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 44

def parent_id
  @parent_id
end

#parent_step_run_idObject

Returns the value of attribute parent_step_run_id.



46
47
48
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 46

def parent_step_run_id
  @parent_step_run_id
end

#started_atObject

Returns the value of attribute started_at.



38
39
40
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 38

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



24
25
26
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 24

def status
  @status
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 20

def tenant_id
  @tenant_id
end

#triggered_byObject

Returns the value of attribute triggered_by.



26
27
28
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 26

def triggered_by
  @triggered_by
end

#workflow_versionObject

Returns the value of attribute workflow_version.



28
29
30
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 28

def workflow_version
  @workflow_version
end

#workflow_version_idObject

Returns the value of attribute workflow_version_id.



22
23
24
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 22

def workflow_version_id
  @workflow_version_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 437

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 73

def self.attribute_map
  {
    :'metadata' => :'metadata',
    :'tenant_id' => :'tenantId',
    :'workflow_version_id' => :'workflowVersionId',
    :'status' => :'status',
    :'triggered_by' => :'triggeredBy',
    :'workflow_version' => :'workflowVersion',
    :'display_name' => :'displayName',
    :'job_runs' => :'jobRuns',
    :'input' => :'input',
    :'error' => :'error',
    :'started_at' => :'startedAt',
    :'finished_at' => :'finishedAt',
    :'duration' => :'duration',
    :'parent_id' => :'parentId',
    :'parent_step_run_id' => :'parentStepRunId',
    :'additional_metadata' => :'additionalMetadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 413

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 105

def self.openapi_types
  {
    :'metadata' => :'APIResourceMeta',
    :'tenant_id' => :'String',
    :'workflow_version_id' => :'String',
    :'status' => :'WorkflowRunStatus',
    :'triggered_by' => :'WorkflowRunTriggeredBy',
    :'workflow_version' => :'WorkflowVersion',
    :'display_name' => :'String',
    :'job_runs' => :'Array<JobRun>',
    :'input' => :'Hash<String, Object>',
    :'error' => :'String',
    :'started_at' => :'Time',
    :'finished_at' => :'Time',
    :'duration' => :'Integer',
    :'parent_id' => :'String',
    :'parent_step_run_id' => :'String',
    :'additional_metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 377

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      tenant_id == o.tenant_id &&
      workflow_version_id == o.workflow_version_id &&
      status == o.status &&
      triggered_by == o.triggered_by &&
      workflow_version == o.workflow_version &&
      display_name == o.display_name &&
      job_runs == o.job_runs &&
      input == o.input &&
      error == o.error &&
      started_at == o.started_at &&
      finished_at == o.finished_at &&
      duration == o.duration &&
      parent_id == o.parent_id &&
      parent_step_run_id == o.parent_step_run_id &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 508

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


400
401
402
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 400

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



406
407
408
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 406

def hash
  [, tenant_id, workflow_version_id, status, triggered_by, workflow_version, display_name, job_runs, input, error, started_at, finished_at, duration, parent_id, parent_step_run_id, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 231

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @workflow_version_id.nil?
    invalid_properties.push('invalid value for "workflow_version_id", workflow_version_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @triggered_by.nil?
    invalid_properties.push('invalid value for "triggered_by", triggered_by cannot be nil.')
  end

  if !@parent_id.nil? && @parent_id.to_s.length > 36
    invalid_properties.push('invalid value for "parent_id", the character length must be smaller than or equal to 36.')
  end

  if !@parent_id.nil? && @parent_id.to_s.length < 36
    invalid_properties.push('invalid value for "parent_id", the character length must be greater than or equal to 36.')
  end

  if !@parent_step_run_id.nil? && @parent_step_run_id.to_s.length > 36
    invalid_properties.push('invalid value for "parent_step_run_id", the character length must be smaller than or equal to 36.')
  end

  if !@parent_step_run_id.nil? && @parent_step_run_id.to_s.length < 36
    invalid_properties.push('invalid value for "parent_step_run_id", the character length must be greater than or equal to 36.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



484
485
486
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 484

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



490
491
492
493
494
495
496
497
498
499
500
501
502
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 490

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



478
479
480
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 478

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/workflow_run.rb', line 275

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metadata.nil?
  return false if @tenant_id.nil?
  return false if @workflow_version_id.nil?
  return false if @status.nil?
  return false if @triggered_by.nil?
  return false if !@parent_id.nil? && @parent_id.to_s.length > 36
  return false if !@parent_id.nil? && @parent_id.to_s.length < 36
  return false if !@parent_step_run_id.nil? && @parent_step_run_id.to_s.length > 36
  return false if !@parent_step_run_id.nil? && @parent_step_run_id.to_s.length < 36
  true
end