Class: HatchetSdkRest::WorkflowRunApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::WorkflowRunApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cron_workflow_trigger_create(tenant, workflow, create_cron_workflow_trigger_request, opts = {}) ⇒ CronWorkflows
Create cron job workflow trigger Create a new cron job workflow trigger for a tenant.
-
#cron_workflow_trigger_create_with_http_info(tenant, workflow, create_cron_workflow_trigger_request, opts = {}) ⇒ Array<(CronWorkflows, Integer, Hash)>
Create cron job workflow trigger Create a new cron job workflow trigger for a tenant.
-
#initialize(api_client = ApiClient.default) ⇒ WorkflowRunApi
constructor
A new instance of WorkflowRunApi.
-
#scheduled_workflow_run_create(tenant, workflow, schedule_workflow_run_request, opts = {}) ⇒ ScheduledWorkflows
Trigger workflow run Schedule a new workflow run for a tenant.
-
#scheduled_workflow_run_create_with_http_info(tenant, workflow, schedule_workflow_run_request, opts = {}) ⇒ Array<(ScheduledWorkflows, Integer, Hash)>
Trigger workflow run Schedule a new workflow run for a tenant.
-
#workflow_run_cancel(tenant, workflow_runs_cancel_request, opts = {}) ⇒ EventUpdateCancel200Response
Cancel workflow runs Cancel a batch of workflow runs.
-
#workflow_run_cancel_with_http_info(tenant, workflow_runs_cancel_request, opts = {}) ⇒ Array<(EventUpdateCancel200Response, Integer, Hash)>
Cancel workflow runs Cancel a batch of workflow runs.
-
#workflow_run_create(workflow, trigger_workflow_run_request, opts = {}) ⇒ WorkflowRun
Trigger workflow run Trigger a new workflow run for a tenant.
-
#workflow_run_create_with_http_info(workflow, trigger_workflow_run_request, opts = {}) ⇒ Array<(WorkflowRun, Integer, Hash)>
Trigger workflow run Trigger a new workflow run for a tenant.
-
#workflow_run_get_input(tenant, workflow_run, opts = {}) ⇒ Hash<String, Object>
Get workflow run input Get the input for a workflow run.
-
#workflow_run_get_input_with_http_info(tenant, workflow_run, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get workflow run input Get the input for a workflow run.
-
#workflow_run_update_replay(tenant, replay_workflow_runs_request, opts = {}) ⇒ ReplayWorkflowRunsResponse
Replay workflow runs Replays a list of workflow runs.
-
#workflow_run_update_replay_with_http_info(tenant, replay_workflow_runs_request, opts = {}) ⇒ Array<(ReplayWorkflowRunsResponse, Integer, Hash)>
Replay workflow runs Replays a list of workflow runs.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WorkflowRunApi
Returns a new instance of WorkflowRunApi.
19 20 21 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cron_workflow_trigger_create(tenant, workflow, create_cron_workflow_trigger_request, opts = {}) ⇒ CronWorkflows
Create cron job workflow trigger Create a new cron job workflow trigger for a tenant
29 30 31 32 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 29 def cron_workflow_trigger_create(tenant, workflow, create_cron_workflow_trigger_request, opts = {}) data, _status_code, _headers = cron_workflow_trigger_create_with_http_info(tenant, workflow, create_cron_workflow_trigger_request, opts) data end |
#cron_workflow_trigger_create_with_http_info(tenant, workflow, create_cron_workflow_trigger_request, opts = {}) ⇒ Array<(CronWorkflows, Integer, Hash)>
Create cron job workflow trigger Create a new cron job workflow trigger for a tenant
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 41 def cron_workflow_trigger_create_with_http_info(tenant, workflow, create_cron_workflow_trigger_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunApi.cron_workflow_trigger_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunApi.cron_workflow_trigger_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.cron_workflow_trigger_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.cron_workflow_trigger_create, the character length must be greater than or equal to 36.' end # verify the required parameter 'workflow' is set if @api_client.config.client_side_validation && workflow.nil? fail ArgumentError, "Missing the required parameter 'workflow' when calling WorkflowRunApi.cron_workflow_trigger_create" end # verify the required parameter 'create_cron_workflow_trigger_request' is set if @api_client.config.client_side_validation && create_cron_workflow_trigger_request.nil? fail ArgumentError, "Missing the required parameter 'create_cron_workflow_trigger_request' when calling WorkflowRunApi.cron_workflow_trigger_create" end # resource path local_var_path = '/api/v1/tenants/{tenant}/workflows/{workflow}/crons'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'workflow' + '}', CGI.escape(workflow.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_cron_workflow_trigger_request) # return_type return_type = opts[:debug_return_type] || 'CronWorkflows' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunApi.cron_workflow_trigger_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunApi#cron_workflow_trigger_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#scheduled_workflow_run_create(tenant, workflow, schedule_workflow_run_request, opts = {}) ⇒ ScheduledWorkflows
Trigger workflow run Schedule a new workflow run for a tenant
117 118 119 120 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 117 def scheduled_workflow_run_create(tenant, workflow, schedule_workflow_run_request, opts = {}) data, _status_code, _headers = scheduled_workflow_run_create_with_http_info(tenant, workflow, schedule_workflow_run_request, opts) data end |
#scheduled_workflow_run_create_with_http_info(tenant, workflow, schedule_workflow_run_request, opts = {}) ⇒ Array<(ScheduledWorkflows, Integer, Hash)>
Trigger workflow run Schedule a new workflow run for a tenant
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 129 def scheduled_workflow_run_create_with_http_info(tenant, workflow, schedule_workflow_run_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunApi.scheduled_workflow_run_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunApi.scheduled_workflow_run_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.scheduled_workflow_run_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.scheduled_workflow_run_create, the character length must be greater than or equal to 36.' end # verify the required parameter 'workflow' is set if @api_client.config.client_side_validation && workflow.nil? fail ArgumentError, "Missing the required parameter 'workflow' when calling WorkflowRunApi.scheduled_workflow_run_create" end # verify the required parameter 'schedule_workflow_run_request' is set if @api_client.config.client_side_validation && schedule_workflow_run_request.nil? fail ArgumentError, "Missing the required parameter 'schedule_workflow_run_request' when calling WorkflowRunApi.scheduled_workflow_run_create" end # resource path local_var_path = '/api/v1/tenants/{tenant}/workflows/{workflow}/scheduled'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'workflow' + '}', CGI.escape(workflow.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(schedule_workflow_run_request) # return_type return_type = opts[:debug_return_type] || 'ScheduledWorkflows' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunApi.scheduled_workflow_run_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunApi#scheduled_workflow_run_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#workflow_run_cancel(tenant, workflow_runs_cancel_request, opts = {}) ⇒ EventUpdateCancel200Response
Cancel workflow runs Cancel a batch of workflow runs
204 205 206 207 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 204 def workflow_run_cancel(tenant, workflow_runs_cancel_request, opts = {}) data, _status_code, _headers = workflow_run_cancel_with_http_info(tenant, workflow_runs_cancel_request, opts) data end |
#workflow_run_cancel_with_http_info(tenant, workflow_runs_cancel_request, opts = {}) ⇒ Array<(EventUpdateCancel200Response, Integer, Hash)>
Cancel workflow runs Cancel a batch of workflow runs
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 215 def workflow_run_cancel_with_http_info(tenant, workflow_runs_cancel_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunApi.workflow_run_cancel ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunApi.workflow_run_cancel" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.workflow_run_cancel, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.workflow_run_cancel, the character length must be greater than or equal to 36.' end # verify the required parameter 'workflow_runs_cancel_request' is set if @api_client.config.client_side_validation && workflow_runs_cancel_request.nil? fail ArgumentError, "Missing the required parameter 'workflow_runs_cancel_request' when calling WorkflowRunApi.workflow_run_cancel" end # resource path local_var_path = '/api/v1/tenants/{tenant}/workflows/cancel'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(workflow_runs_cancel_request) # return_type return_type = opts[:debug_return_type] || 'EventUpdateCancel200Response' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunApi.workflow_run_cancel", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunApi#workflow_run_cancel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#workflow_run_create(workflow, trigger_workflow_run_request, opts = {}) ⇒ WorkflowRun
Trigger workflow run Trigger a new workflow run for a tenant
287 288 289 290 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 287 def workflow_run_create(workflow, trigger_workflow_run_request, opts = {}) data, _status_code, _headers = workflow_run_create_with_http_info(workflow, trigger_workflow_run_request, opts) data end |
#workflow_run_create_with_http_info(workflow, trigger_workflow_run_request, opts = {}) ⇒ Array<(WorkflowRun, Integer, Hash)>
Trigger workflow run Trigger a new workflow run for a tenant
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 299 def workflow_run_create_with_http_info(workflow, trigger_workflow_run_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunApi.workflow_run_create ...' end # verify the required parameter 'workflow' is set if @api_client.config.client_side_validation && workflow.nil? fail ArgumentError, "Missing the required parameter 'workflow' when calling WorkflowRunApi.workflow_run_create" end if @api_client.config.client_side_validation && workflow.to_s.length > 36 fail ArgumentError, 'invalid value for "workflow" when calling WorkflowRunApi.workflow_run_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && workflow.to_s.length < 36 fail ArgumentError, 'invalid value for "workflow" when calling WorkflowRunApi.workflow_run_create, the character length must be greater than or equal to 36.' end # verify the required parameter 'trigger_workflow_run_request' is set if @api_client.config.client_side_validation && trigger_workflow_run_request.nil? fail ArgumentError, "Missing the required parameter 'trigger_workflow_run_request' when calling WorkflowRunApi.workflow_run_create" end if @api_client.config.client_side_validation && !opts[:'version'].nil? && opts[:'version'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"version"]" when calling WorkflowRunApi.workflow_run_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'version'].nil? && opts[:'version'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"version"]" when calling WorkflowRunApi.workflow_run_create, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/workflows/{workflow}/trigger'.sub('{' + 'workflow' + '}', CGI.escape(workflow.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(trigger_workflow_run_request) # return_type return_type = opts[:debug_return_type] || 'WorkflowRun' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunApi.workflow_run_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunApi#workflow_run_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#workflow_run_get_input(tenant, workflow_run, opts = {}) ⇒ Hash<String, Object>
Get workflow run input Get the input for a workflow run.
379 380 381 382 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 379 def workflow_run_get_input(tenant, workflow_run, opts = {}) data, _status_code, _headers = workflow_run_get_input_with_http_info(tenant, workflow_run, opts) data end |
#workflow_run_get_input_with_http_info(tenant, workflow_run, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get workflow run input Get the input for a workflow run.
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 390 def workflow_run_get_input_with_http_info(tenant, workflow_run, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunApi.workflow_run_get_input ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunApi.workflow_run_get_input" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.workflow_run_get_input, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.workflow_run_get_input, the character length must be greater than or equal to 36.' end # verify the required parameter 'workflow_run' is set if @api_client.config.client_side_validation && workflow_run.nil? fail ArgumentError, "Missing the required parameter 'workflow_run' when calling WorkflowRunApi.workflow_run_get_input" end if @api_client.config.client_side_validation && workflow_run.to_s.length > 36 fail ArgumentError, 'invalid value for "workflow_run" when calling WorkflowRunApi.workflow_run_get_input, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && workflow_run.to_s.length < 36 fail ArgumentError, 'invalid value for "workflow_run" when calling WorkflowRunApi.workflow_run_get_input, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/tenants/{tenant}/workflow-runs/{workflow-run}/input'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'workflow-run' + '}', CGI.escape(workflow_run.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunApi.workflow_run_get_input", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunApi#workflow_run_get_input\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#workflow_run_update_replay(tenant, replay_workflow_runs_request, opts = {}) ⇒ ReplayWorkflowRunsResponse
Replay workflow runs Replays a list of workflow runs.
464 465 466 467 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 464 def workflow_run_update_replay(tenant, replay_workflow_runs_request, opts = {}) data, _status_code, _headers = workflow_run_update_replay_with_http_info(tenant, replay_workflow_runs_request, opts) data end |
#workflow_run_update_replay_with_http_info(tenant, replay_workflow_runs_request, opts = {}) ⇒ Array<(ReplayWorkflowRunsResponse, Integer, Hash)>
Replay workflow runs Replays a list of workflow runs.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_run_api.rb', line 475 def workflow_run_update_replay_with_http_info(tenant, replay_workflow_runs_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunApi.workflow_run_update_replay ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunApi.workflow_run_update_replay" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.workflow_run_update_replay, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunApi.workflow_run_update_replay, the character length must be greater than or equal to 36.' end # verify the required parameter 'replay_workflow_runs_request' is set if @api_client.config.client_side_validation && replay_workflow_runs_request.nil? fail ArgumentError, "Missing the required parameter 'replay_workflow_runs_request' when calling WorkflowRunApi.workflow_run_update_replay" end # resource path local_var_path = '/api/v1/tenants/{tenant}/workflow-runs/replay'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(replay_workflow_runs_request) # return_type return_type = opts[:debug_return_type] || 'ReplayWorkflowRunsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunApi.workflow_run_update_replay", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunApi#workflow_run_update_replay\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |