Class: Hatchet::Features::Tenant
- Inherits:
-
Object
- Object
- Hatchet::Features::Tenant
- Defined in:
- lib/hatchet/features/tenant.rb
Overview
Tenant client for interacting with the current Hatchet tenant
This class provides a high-level interface for retrieving tenant information from the Hatchet system.
Instance Method Summary collapse
-
#get ⇒ Object
Get the current tenant.
-
#initialize(rest_client, config) ⇒ void
constructor
Initializes a new Tenant client instance.
Constructor Details
#initialize(rest_client, config) ⇒ void
Initializes a new Tenant client instance
21 22 23 24 25 |
# File 'lib/hatchet/features/tenant.rb', line 21 def initialize(rest_client, config) @rest_client = rest_client @config = config @tenant_api = HatchetSdkRest::TenantApi.new(rest_client) end |
Instance Method Details
#get ⇒ Object
Get the current tenant
33 34 35 |
# File 'lib/hatchet/features/tenant.rb', line 33 def get @tenant_api.tenant_get(@config.tenant_id) end |