Class: HatchetSdkRest::CELApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::CELApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/cel_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ CELApi
constructor
A new instance of CELApi.
-
#v1_cel_debug(tenant, v1_cel_debug_request, opts = {}) ⇒ V1CELDebugResponse
Debug a CEL expression Evaluate a CEL expression against provided input data.
-
#v1_cel_debug_with_http_info(tenant, v1_cel_debug_request, opts = {}) ⇒ Array<(V1CELDebugResponse, Integer, Hash)>
Debug a CEL expression Evaluate a CEL expression against provided input data.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/cel_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_cel_debug(tenant, v1_cel_debug_request, opts = {}) ⇒ V1CELDebugResponse
Debug a CEL expression Evaluate a CEL expression against provided input data.
28 29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/cel_api.rb', line 28 def v1_cel_debug(tenant, v1_cel_debug_request, opts = {}) data, _status_code, _headers = v1_cel_debug_with_http_info(tenant, v1_cel_debug_request, opts) data end |
#v1_cel_debug_with_http_info(tenant, v1_cel_debug_request, opts = {}) ⇒ Array<(V1CELDebugResponse, Integer, Hash)>
Debug a CEL expression Evaluate a CEL expression against provided input data.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/cel_api.rb', line 39 def v1_cel_debug_with_http_info(tenant, v1_cel_debug_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CELApi.v1_cel_debug ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling CELApi.v1_cel_debug" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling CELApi.v1_cel_debug, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling CELApi.v1_cel_debug, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_cel_debug_request' is set if @api_client.config.client_side_validation && v1_cel_debug_request.nil? fail ArgumentError, "Missing the required parameter 'v1_cel_debug_request' when calling CELApi.v1_cel_debug" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/cel/debug'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_cel_debug_request) # return_type return_type = opts[:debug_return_type] || 'V1CELDebugResponse' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"CELApi.v1_cel_debug", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CELApi#v1_cel_debug\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |