Class: HatchetSdkRest::LogApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::LogApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb,
sig/hatchet_sdk_rest.rbs
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LogApi
constructor
A new instance of LogApi.
-
#v1_log_line_list(task, opts = {}) ⇒ V1LogLineList
List log lines Lists log lines for a task.
-
#v1_log_line_list_with_http_info(task, opts = {}) ⇒ Array<(V1LogLineList, Integer, Hash)>
List log lines Lists log lines for a task.
-
#v1_tenant_log_line_get_point_metrics(tenant, opts = {}) ⇒ V1LogsPointMetrics
Get log point metrics Get a minute by minute breakdown of log metrics for a tenant.
-
#v1_tenant_log_line_get_point_metrics_with_http_info(tenant, opts = {}) ⇒ Array<(V1LogsPointMetrics, Integer, Hash)>
Get log point metrics Get a minute by minute breakdown of log metrics for a tenant.
-
#v1_tenant_log_line_list(tenant, opts = {}) ⇒ V1LogLineList
List log lines Lists log lines for a tenant.
-
#v1_tenant_log_line_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1LogLineList, Integer, Hash)>
List log lines Lists log lines for a tenant.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_log_line_list(task, opts = {}) ⇒ V1LogLineList
List log lines Lists log lines for a task
34 35 36 37 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 34 def v1_log_line_list(task, opts = {}) data, _status_code, _headers = v1_log_line_list_with_http_info(task, opts) data end |
#v1_log_line_list_with_http_info(task, opts = {}) ⇒ Array<(V1LogLineList, Integer, Hash)>
List log lines Lists log lines for a task
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 51 def v1_log_line_list_with_http_info(task, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogApi.v1_log_line_list ...' end # verify the required parameter 'task' is set if @api_client.config.client_side_validation && task.nil? fail ArgumentError, "Missing the required parameter 'task' when calling LogApi.v1_log_line_list" end if @api_client.config.client_side_validation && task.to_s.length > 36 fail ArgumentError, 'invalid value for "task" when calling LogApi.v1_log_line_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && task.to_s.length < 36 fail ArgumentError, 'invalid value for "task" when calling LogApi.v1_log_line_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tasks/{task}/logs'.sub('{' + 'task' + '}', CGI.escape(task.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'since'] = opts[:'since'] if !opts[:'since'].nil? query_params[:'until'] = opts[:'_until'] if !opts[:'_until'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'levels'] = @api_client.build_collection_param(opts[:'levels'], :multi) if !opts[:'levels'].nil? query_params[:'order_by_direction'] = opts[:'order_by_direction'] if !opts[:'order_by_direction'].nil? query_params[:'attempt'] = opts[:'attempt'] if !opts[:'attempt'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1LogLineList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"LogApi.v1_log_line_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogApi#v1_log_line_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_tenant_log_line_get_point_metrics(tenant, opts = {}) ⇒ V1LogsPointMetrics
Get log point metrics Get a minute by minute breakdown of log metrics for a tenant
126 127 128 129 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 126 def v1_tenant_log_line_get_point_metrics(tenant, opts = {}) data, _status_code, _headers = v1_tenant_log_line_get_point_metrics_with_http_info(tenant, opts) data end |
#v1_tenant_log_line_get_point_metrics_with_http_info(tenant, opts = {}) ⇒ Array<(V1LogsPointMetrics, Integer, Hash)>
Get log point metrics Get a minute by minute breakdown of log metrics for a tenant
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 143 def v1_tenant_log_line_get_point_metrics_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogApi.v1_tenant_log_line_get_point_metrics ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling LogApi.v1_tenant_log_line_get_point_metrics" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling LogApi.v1_tenant_log_line_get_point_metrics, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling LogApi.v1_tenant_log_line_get_point_metrics, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/log-point-metrics'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'since'] = opts[:'since'] if !opts[:'since'].nil? query_params[:'until'] = opts[:'_until'] if !opts[:'_until'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'levels'] = @api_client.build_collection_param(opts[:'levels'], :multi) if !opts[:'levels'].nil? query_params[:'taskExternalIds'] = @api_client.build_collection_param(opts[:'task_external_ids'], :multi) if !opts[:'task_external_ids'].nil? query_params[:'workflow_ids'] = @api_client.build_collection_param(opts[:'workflow_ids'], :multi) if !opts[:'workflow_ids'].nil? query_params[:'step_ids'] = @api_client.build_collection_param(opts[:'step_ids'], :multi) if !opts[:'step_ids'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1LogsPointMetrics' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"LogApi.v1_tenant_log_line_get_point_metrics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogApi#v1_tenant_log_line_get_point_metrics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_tenant_log_line_list(tenant, opts = {}) ⇒ V1LogLineList
List log lines Lists log lines for a tenant
221 222 223 224 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 221 def v1_tenant_log_line_list(tenant, opts = {}) data, _status_code, _headers = v1_tenant_log_line_list_with_http_info(tenant, opts) data end |
#v1_tenant_log_line_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1LogLineList, Integer, Hash)>
List log lines Lists log lines for a tenant
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 241 def v1_tenant_log_line_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogApi.v1_tenant_log_line_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling LogApi.v1_tenant_log_line_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling LogApi.v1_tenant_log_line_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling LogApi.v1_tenant_log_line_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/logs'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'since'] = opts[:'since'] if !opts[:'since'].nil? query_params[:'until'] = opts[:'_until'] if !opts[:'_until'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'levels'] = @api_client.build_collection_param(opts[:'levels'], :multi) if !opts[:'levels'].nil? query_params[:'order_by_direction'] = opts[:'order_by_direction'] if !opts[:'order_by_direction'].nil? query_params[:'attempt'] = opts[:'attempt'] if !opts[:'attempt'].nil? query_params[:'taskExternalIds'] = @api_client.build_collection_param(opts[:'task_external_ids'], :multi) if !opts[:'task_external_ids'].nil? query_params[:'workflow_ids'] = @api_client.build_collection_param(opts[:'workflow_ids'], :multi) if !opts[:'workflow_ids'].nil? query_params[:'step_ids'] = @api_client.build_collection_param(opts[:'step_ids'], :multi) if !opts[:'step_ids'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1LogLineList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"LogApi.v1_tenant_log_line_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogApi#v1_tenant_log_line_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |