Class: HatchetSdkRest::LogApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::LogApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LogApi
constructor
A new instance of LogApi.
-
#log_line_list(step_run, opts = {}) ⇒ LogLineList
List log lines Lists log lines for a step run.
-
#log_line_list_with_http_info(step_run, opts = {}) ⇒ Array<(LogLineList, Integer, Hash)>
List log lines Lists log lines for a step run.
-
#v1_log_line_list(task, opts = {}) ⇒ V1LogLineList
List log lines Lists log lines for a task.
-
#v1_log_line_list_with_http_info(task, opts = {}) ⇒ Array<(V1LogLineList, Integer, Hash)>
List log lines Lists log lines for a task.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#log_line_list(step_run, opts = {}) ⇒ LogLineList
List log lines Lists log lines for a step run.
33 34 35 36 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 33 def log_line_list(step_run, opts = {}) data, _status_code, _headers = log_line_list_with_http_info(step_run, opts) data end |
#log_line_list_with_http_info(step_run, opts = {}) ⇒ Array<(LogLineList, Integer, Hash)>
List log lines Lists log lines for a step run.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 49 def log_line_list_with_http_info(step_run, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogApi.log_line_list ...' end # verify the required parameter 'step_run' is set if @api_client.config.client_side_validation && step_run.nil? fail ArgumentError, "Missing the required parameter 'step_run' when calling LogApi.log_line_list" end if @api_client.config.client_side_validation && step_run.to_s.length > 36 fail ArgumentError, 'invalid value for "step_run" when calling LogApi.log_line_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && step_run.to_s.length < 36 fail ArgumentError, 'invalid value for "step_run" when calling LogApi.log_line_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/step-runs/{step-run}/logs'.sub('{' + 'step-run' + '}', CGI.escape(step_run.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'levels'] = @api_client.build_collection_param(opts[:'levels'], :multi) if !opts[:'levels'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'orderByField'] = opts[:'order_by_field'] if !opts[:'order_by_field'].nil? query_params[:'orderByDirection'] = opts[:'order_by_direction'] if !opts[:'order_by_direction'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LogLineList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"LogApi.log_line_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogApi#log_line_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_log_line_list(task, opts = {}) ⇒ V1LogLineList
List log lines Lists log lines for a task
123 124 125 126 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 123 def v1_log_line_list(task, opts = {}) data, _status_code, _headers = v1_log_line_list_with_http_info(task, opts) data end |
#v1_log_line_list_with_http_info(task, opts = {}) ⇒ Array<(V1LogLineList, Integer, Hash)>
List log lines Lists log lines for a task
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/log_api.rb', line 140 def v1_log_line_list_with_http_info(task, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogApi.v1_log_line_list ...' end # verify the required parameter 'task' is set if @api_client.config.client_side_validation && task.nil? fail ArgumentError, "Missing the required parameter 'task' when calling LogApi.v1_log_line_list" end if @api_client.config.client_side_validation && task.to_s.length > 36 fail ArgumentError, 'invalid value for "task" when calling LogApi.v1_log_line_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && task.to_s.length < 36 fail ArgumentError, 'invalid value for "task" when calling LogApi.v1_log_line_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tasks/{task}/logs'.sub('{' + 'task' + '}', CGI.escape(task.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'since'] = opts[:'since'] if !opts[:'since'].nil? query_params[:'until'] = opts[:'_until'] if !opts[:'_until'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'levels'] = @api_client.build_collection_param(opts[:'levels'], :multi) if !opts[:'levels'].nil? query_params[:'order_by_direction'] = opts[:'order_by_direction'] if !opts[:'order_by_direction'].nil? query_params[:'attempt'] = opts[:'attempt'] if !opts[:'attempt'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1LogLineList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"LogApi.v1_log_line_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogApi#v1_log_line_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |