Class: HatchetSdkRest::ObservabilityApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::ObservabilityApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/observability_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ObservabilityApi
constructor
A new instance of ObservabilityApi.
-
#v1_observability_get_trace(tenant, run_external_id, opts = {}) ⇒ OtelSpanList
Get OTel trace Get OTel trace for a workflow run.
-
#v1_observability_get_trace_with_http_info(tenant, run_external_id, opts = {}) ⇒ Array<(OtelSpanList, Integer, Hash)>
Get OTel trace Get OTel trace for a workflow run.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ObservabilityApi
Returns a new instance of ObservabilityApi.
19 20 21 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/observability_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/observability_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_observability_get_trace(tenant, run_external_id, opts = {}) ⇒ OtelSpanList
Get OTel trace Get OTel trace for a workflow run
30 31 32 33 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/observability_api.rb', line 30 def v1_observability_get_trace(tenant, run_external_id, opts = {}) data, _status_code, _headers = v1_observability_get_trace_with_http_info(tenant, run_external_id, opts) data end |
#v1_observability_get_trace_with_http_info(tenant, run_external_id, opts = {}) ⇒ Array<(OtelSpanList, Integer, Hash)>
Get OTel trace Get OTel trace for a workflow run
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/observability_api.rb', line 43 def v1_observability_get_trace_with_http_info(tenant, run_external_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ObservabilityApi.v1_observability_get_trace ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling ObservabilityApi.v1_observability_get_trace" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling ObservabilityApi.v1_observability_get_trace, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling ObservabilityApi.v1_observability_get_trace, the character length must be greater than or equal to 36.' end # verify the required parameter 'run_external_id' is set if @api_client.config.client_side_validation && run_external_id.nil? fail ArgumentError, "Missing the required parameter 'run_external_id' when calling ObservabilityApi.v1_observability_get_trace" end if @api_client.config.client_side_validation && run_external_id.to_s.length > 36 fail ArgumentError, 'invalid value for "run_external_id" when calling ObservabilityApi.v1_observability_get_trace, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && run_external_id.to_s.length < 36 fail ArgumentError, 'invalid value for "run_external_id" when calling ObservabilityApi.v1_observability_get_trace, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/traces'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'run_external_id'] = run_external_id query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OtelSpanList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"ObservabilityApi.v1_observability_get_trace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ObservabilityApi#v1_observability_get_trace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |