Class: HatchetSdkRest::WebhookApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::WebhookApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ WebhookApi
constructor
A new instance of WebhookApi.
-
#v1_webhook_create(tenant, v1_create_webhook_request, opts = {}) ⇒ V1Webhook
Create a webhook Create a new webhook.
-
#v1_webhook_create_with_http_info(tenant, v1_create_webhook_request, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Create a webhook Create a new webhook.
-
#v1_webhook_delete(tenant, v1_webhook, opts = {}) ⇒ V1Webhook
Delete a webhook.
-
#v1_webhook_delete_with_http_info(tenant, v1_webhook, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Delete a webhook.
-
#v1_webhook_get(tenant, v1_webhook, opts = {}) ⇒ V1Webhook
Get a webhook Get a webhook by its name.
-
#v1_webhook_get_with_http_info(tenant, v1_webhook, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Get a webhook Get a webhook by its name.
-
#v1_webhook_list(tenant, opts = {}) ⇒ V1WebhookList
List webhooks Lists all webhook for a tenant.
-
#v1_webhook_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1WebhookList, Integer, Hash)>
List webhooks Lists all webhook for a tenant.
-
#v1_webhook_receive(tenant, v1_webhook, opts = {}) ⇒ V1WebhookResponse
Post a webhook message Post an incoming webhook message.
-
#v1_webhook_receive_with_http_info(tenant, v1_webhook, opts = {}) ⇒ Array<(V1WebhookResponse, Integer, Hash)>
Post a webhook message Post an incoming webhook message.
-
#v1_webhook_update(tenant, v1_webhook, v1_update_webhook_request, opts = {}) ⇒ V1Webhook
Update a webhook Update a webhook.
-
#v1_webhook_update_with_http_info(tenant, v1_webhook, v1_update_webhook_request, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Update a webhook Update a webhook.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhookApi
Returns a new instance of WebhookApi.
19 20 21 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_webhook_create(tenant, v1_create_webhook_request, opts = {}) ⇒ V1Webhook
Create a webhook Create a new webhook
28 29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 28 def v1_webhook_create(tenant, v1_create_webhook_request, opts = {}) data, _status_code, _headers = v1_webhook_create_with_http_info(tenant, v1_create_webhook_request, opts) data end |
#v1_webhook_create_with_http_info(tenant, v1_create_webhook_request, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Create a webhook Create a new webhook
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 39 def v1_webhook_create_with_http_info(tenant, v1_create_webhook_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookApi.v1_webhook_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WebhookApi.v1_webhook_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_create, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_create_webhook_request' is set if @api_client.config.client_side_validation && v1_create_webhook_request.nil? fail ArgumentError, "Missing the required parameter 'v1_create_webhook_request' when calling WebhookApi.v1_webhook_create" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/webhooks'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_create_webhook_request) # return_type return_type = opts[:debug_return_type] || 'V1Webhook' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WebhookApi.v1_webhook_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookApi#v1_webhook_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_webhook_delete(tenant, v1_webhook, opts = {}) ⇒ V1Webhook
Delete a webhook
109 110 111 112 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 109 def v1_webhook_delete(tenant, v1_webhook, opts = {}) data, _status_code, _headers = v1_webhook_delete_with_http_info(tenant, v1_webhook, opts) data end |
#v1_webhook_delete_with_http_info(tenant, v1_webhook, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Delete a webhook
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 119 def v1_webhook_delete_with_http_info(tenant, v1_webhook, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookApi.v1_webhook_delete ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WebhookApi.v1_webhook_delete" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_delete, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_delete, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_webhook' is set if @api_client.config.client_side_validation && v1_webhook.nil? fail ArgumentError, "Missing the required parameter 'v1_webhook' when calling WebhookApi.v1_webhook_delete" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/webhooks/{v1-webhook}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-webhook' + '}', CGI.escape(v1_webhook.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1Webhook' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WebhookApi.v1_webhook_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookApi#v1_webhook_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_webhook_get(tenant, v1_webhook, opts = {}) ⇒ V1Webhook
Get a webhook Get a webhook by its name
185 186 187 188 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 185 def v1_webhook_get(tenant, v1_webhook, opts = {}) data, _status_code, _headers = v1_webhook_get_with_http_info(tenant, v1_webhook, opts) data end |
#v1_webhook_get_with_http_info(tenant, v1_webhook, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Get a webhook Get a webhook by its name
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 196 def v1_webhook_get_with_http_info(tenant, v1_webhook, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookApi.v1_webhook_get ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WebhookApi.v1_webhook_get" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_get, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_webhook' is set if @api_client.config.client_side_validation && v1_webhook.nil? fail ArgumentError, "Missing the required parameter 'v1_webhook' when calling WebhookApi.v1_webhook_get" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/webhooks/{v1-webhook}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-webhook' + '}', CGI.escape(v1_webhook.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1Webhook' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WebhookApi.v1_webhook_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookApi#v1_webhook_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_webhook_list(tenant, opts = {}) ⇒ V1WebhookList
List webhooks Lists all webhook for a tenant.
265 266 267 268 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 265 def v1_webhook_list(tenant, opts = {}) data, _status_code, _headers = v1_webhook_list_with_http_info(tenant, opts) data end |
#v1_webhook_list_with_http_info(tenant, opts = {}) ⇒ Array<(V1WebhookList, Integer, Hash)>
List webhooks Lists all webhook for a tenant.
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 279 def v1_webhook_list_with_http_info(tenant, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookApi.v1_webhook_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WebhookApi.v1_webhook_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/webhooks'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sourceNames'] = @api_client.build_collection_param(opts[:'source_names'], :multi) if !opts[:'source_names'].nil? query_params[:'webhookNames'] = @api_client.build_collection_param(opts[:'webhook_names'], :multi) if !opts[:'webhook_names'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1WebhookList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WebhookApi.v1_webhook_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookApi#v1_webhook_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_webhook_receive(tenant, v1_webhook, opts = {}) ⇒ V1WebhookResponse
Post a webhook message Post an incoming webhook message
345 346 347 348 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 345 def v1_webhook_receive(tenant, v1_webhook, opts = {}) data, _status_code, _headers = v1_webhook_receive_with_http_info(tenant, v1_webhook, opts) data end |
#v1_webhook_receive_with_http_info(tenant, v1_webhook, opts = {}) ⇒ Array<(V1WebhookResponse, Integer, Hash)>
Post a webhook message Post an incoming webhook message
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 356 def v1_webhook_receive_with_http_info(tenant, v1_webhook, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookApi.v1_webhook_receive ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WebhookApi.v1_webhook_receive" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_receive, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_receive, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_webhook' is set if @api_client.config.client_side_validation && v1_webhook.nil? fail ArgumentError, "Missing the required parameter 'v1_webhook' when calling WebhookApi.v1_webhook_receive" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/webhooks/{v1-webhook}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-webhook' + '}', CGI.escape(v1_webhook.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1WebhookResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"WebhookApi.v1_webhook_receive", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookApi#v1_webhook_receive\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_webhook_update(tenant, v1_webhook, v1_update_webhook_request, opts = {}) ⇒ V1Webhook
Update a webhook Update a webhook
423 424 425 426 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 423 def v1_webhook_update(tenant, v1_webhook, v1_update_webhook_request, opts = {}) data, _status_code, _headers = v1_webhook_update_with_http_info(tenant, v1_webhook, v1_update_webhook_request, opts) data end |
#v1_webhook_update_with_http_info(tenant, v1_webhook, v1_update_webhook_request, opts = {}) ⇒ Array<(V1Webhook, Integer, Hash)>
Update a webhook Update a webhook
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/webhook_api.rb', line 435 def v1_webhook_update_with_http_info(tenant, v1_webhook, v1_update_webhook_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookApi.v1_webhook_update ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WebhookApi.v1_webhook_update" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_update, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WebhookApi.v1_webhook_update, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_webhook' is set if @api_client.config.client_side_validation && v1_webhook.nil? fail ArgumentError, "Missing the required parameter 'v1_webhook' when calling WebhookApi.v1_webhook_update" end # verify the required parameter 'v1_update_webhook_request' is set if @api_client.config.client_side_validation && v1_update_webhook_request.nil? fail ArgumentError, "Missing the required parameter 'v1_update_webhook_request' when calling WebhookApi.v1_webhook_update" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/webhooks/{v1-webhook}'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)).sub('{' + 'v1-webhook' + '}', CGI.escape(v1_webhook.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_update_webhook_request) # return_type return_type = opts[:debug_return_type] || 'V1Webhook' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WebhookApi.v1_webhook_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookApi#v1_webhook_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |