Class: HatchetSdkRest::Worker

Inherits:
Object
  • Object
show all
Defined in:
lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Worker

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `HatchetSdkRest::Worker` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `HatchetSdkRest::Worker`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'last_heartbeat_at')
    self.last_heartbeat_at = attributes[:'last_heartbeat_at']
  end

  if attributes.key?(:'last_listener_established')
    self.last_listener_established = attributes[:'last_listener_established']
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'registered_workflows')
    if (value = attributes[:'registered_workflows']).is_a?(Array)
      self.registered_workflows = value
    end
  end

  if attributes.key?(:'slots')
    if (value = attributes[:'slots']).is_a?(Array)
      self.slots = value
    end
  end

  if attributes.key?(:'recent_step_runs')
    if (value = attributes[:'recent_step_runs']).is_a?(Array)
      self.recent_step_runs = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'slot_config')
    if (value = attributes[:'slot_config']).is_a?(Hash)
      self.slot_config = value
    end
  end

  if attributes.key?(:'dispatcher_id')
    self.dispatcher_id = attributes[:'dispatcher_id']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end

  if attributes.key?(:'webhook_url')
    self.webhook_url = attributes[:'webhook_url']
  end

  if attributes.key?(:'webhook_id')
    self.webhook_id = attributes[:'webhook_id']
  end

  if attributes.key?(:'runtime_info')
    self.runtime_info = attributes[:'runtime_info']
  end
end

Instance Attribute Details

#actionsObject

The actions this worker can perform.



32
33
34
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 32

def actions
  @actions
end

#dispatcher_idObject

the id of the assigned dispatcher, in UUID format



50
51
52
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 50

def dispatcher_id
  @dispatcher_id
end

#labelsObject

The current label state of the worker.



53
54
55
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 53

def labels
  @labels
end

#last_heartbeat_atObject

The time this worker last sent a heartbeat.



26
27
28
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 26

def last_heartbeat_at
  @last_heartbeat_at
end

#last_listener_establishedObject

The time this worker last sent a heartbeat.



29
30
31
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 29

def last_listener_established
  @last_listener_established
end

#metadataObject

Returns the value of attribute metadata.



18
19
20
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 18

def 
  @metadata
end

#nameObject

The name of the worker.



21
22
23
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 21

def name
  @name
end

#recent_step_runsObject

The recent step runs for the worker.



41
42
43
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 41

def recent_step_runs
  @recent_step_runs
end

#registered_workflowsObject

The workflow ids registered on this worker.



35
36
37
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 35

def registered_workflows
  @registered_workflows
end

#runtime_infoObject

Returns the value of attribute runtime_info.



61
62
63
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 61

def runtime_info
  @runtime_info
end

#slot_configObject

Slot availability and limits for this worker (slot_type -> { available, limit }).



47
48
49
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 47

def slot_config
  @slot_config
end

#slotsObject

The semaphore slot state for the worker.



38
39
40
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 38

def slots
  @slots
end

#statusObject

The status of the worker.



44
45
46
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 44

def status
  @status
end

#typeObject

Returns the value of attribute type.



23
24
25
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 23

def type
  @type
end

#webhook_idObject

The webhook ID for the worker.



59
60
61
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 59

def webhook_id
  @webhook_id
end

#webhook_urlObject

The webhook URL for the worker.



56
57
58
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 56

def webhook_url
  @webhook_url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 406

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = HatchetSdkRest.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



108
109
110
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 108

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



113
114
115
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 113

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 86

def self.attribute_map
  {
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'type' => :'type',
    :'last_heartbeat_at' => :'lastHeartbeatAt',
    :'last_listener_established' => :'lastListenerEstablished',
    :'actions' => :'actions',
    :'registered_workflows' => :'registeredWorkflows',
    :'slots' => :'slots',
    :'recent_step_runs' => :'recentStepRuns',
    :'status' => :'status',
    :'slot_config' => :'slotConfig',
    :'dispatcher_id' => :'dispatcherId',
    :'labels' => :'labels',
    :'webhook_url' => :'webhookUrl',
    :'webhook_id' => :'webhookId',
    :'runtime_info' => :'runtimeInfo'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 382

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 140

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 118

def self.openapi_types
  {
    :'metadata' => :'APIResourceMeta',
    :'name' => :'String',
    :'type' => :'WorkerType',
    :'last_heartbeat_at' => :'Time',
    :'last_listener_established' => :'Time',
    :'actions' => :'Array<String>',
    :'registered_workflows' => :'Array<RegisteredWorkflow>',
    :'slots' => :'Array<SemaphoreSlots>',
    :'recent_step_runs' => :'Array<RecentStepRuns>',
    :'status' => :'String',
    :'slot_config' => :'Hash<String, WorkerSlotConfig>',
    :'dispatcher_id' => :'String',
    :'labels' => :'Array<WorkerLabel>',
    :'webhook_url' => :'String',
    :'webhook_id' => :'String',
    :'runtime_info' => :'WorkerRuntimeInfo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 346

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      type == o.type &&
      last_heartbeat_at == o.last_heartbeat_at &&
      last_listener_established == o.last_listener_established &&
      actions == o.actions &&
      registered_workflows == o.registered_workflows &&
      slots == o.slots &&
      recent_step_runs == o.recent_step_runs &&
      status == o.status &&
      slot_config == o.slot_config &&
      dispatcher_id == o.dispatcher_id &&
      labels == o.labels &&
      webhook_url == o.webhook_url &&
      webhook_id == o.webhook_id &&
      runtime_info == o.runtime_info
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 477

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


369
370
371
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 369

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



375
376
377
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 375

def hash
  [, name, type, last_heartbeat_at, last_listener_established, actions, registered_workflows, slots, recent_step_runs, status, slot_config, dispatcher_id, labels, webhook_url, webhook_id, runtime_info].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 246

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@dispatcher_id.nil? && @dispatcher_id.to_s.length > 36
    invalid_properties.push('invalid value for "dispatcher_id", the character length must be smaller than or equal to 36.')
  end

  if !@dispatcher_id.nil? && @dispatcher_id.to_s.length < 36
    invalid_properties.push('invalid value for "dispatcher_id", the character length must be greater than or equal to 36.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



453
454
455
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 453

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 459

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



447
448
449
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 447

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



274
275
276
277
278
279
280
281
282
283
284
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/models/worker.rb', line 274

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @metadata.nil?
  return false if @name.nil?
  return false if @type.nil?
  status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "INACTIVE", "PAUSED"])
  return false unless status_validator.valid?(@status)
  return false if !@dispatcher_id.nil? && @dispatcher_id.to_s.length > 36
  return false if !@dispatcher_id.nil? && @dispatcher_id.to_s.length < 36
  true
end