Class: HatchetSdkRest::WorkflowRunsApi
- Inherits:
-
Object
- Object
- HatchetSdkRest::WorkflowRunsApi
- Defined in:
- lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb,
sig/hatchet_sdk_rest.rbs
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ WorkflowRunsApi
constructor
A new instance of WorkflowRunsApi.
-
#v1_durable_task_branch(tenant, v1_branch_durable_task_request, opts = {}) ⇒ V1BranchDurableTaskResponse
Branch durable task Branch a durable task from a specific node, creating a new branch and re-processing its matches.
-
#v1_durable_task_branch_with_http_info(tenant, v1_branch_durable_task_request, opts = {}) ⇒ Array<(V1BranchDurableTaskResponse, Integer, Hash)>
Branch durable task Branch a durable task from a specific node, creating a new branch and re-processing its matches.
-
#v1_workflow_run_create(tenant, v1_trigger_workflow_run_request, opts = {}) ⇒ V1WorkflowRunDetails
Create workflow run Trigger a new workflow run.
-
#v1_workflow_run_create_with_http_info(tenant, v1_trigger_workflow_run_request, opts = {}) ⇒ Array<(V1WorkflowRunDetails, Integer, Hash)>
Create workflow run Trigger a new workflow run.
-
#v1_workflow_run_display_names_list(tenant, external_ids, opts = {}) ⇒ V1WorkflowRunDisplayNameList
List workflow runs Lists displayable names of workflow runs for a tenant.
-
#v1_workflow_run_display_names_list_with_http_info(tenant, external_ids, opts = {}) ⇒ Array<(V1WorkflowRunDisplayNameList, Integer, Hash)>
List workflow runs Lists displayable names of workflow runs for a tenant.
-
#v1_workflow_run_external_ids_list(tenant, since, opts = {}) ⇒ Array<String>
List workflow run external ids Lists external ids for workflow runs matching filters.
-
#v1_workflow_run_external_ids_list_with_http_info(tenant, since, opts = {}) ⇒ Array<(Array<String>, Integer, Hash)>
List workflow run external ids Lists external ids for workflow runs matching filters.
-
#v1_workflow_run_get(v1_workflow_run, opts = {}) ⇒ V1WorkflowRunDetails
List tasks Get a workflow run and its metadata to display on the "detail" page.
-
#v1_workflow_run_get_status(v1_workflow_run, opts = {}) ⇒ V1TaskStatus
Get workflow run status Get the status of a workflow run.
-
#v1_workflow_run_get_status_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1TaskStatus, Integer, Hash)>
Get workflow run status Get the status of a workflow run.
-
#v1_workflow_run_get_timings(v1_workflow_run, opts = {}) ⇒ V1TaskTimingList
List timings for a workflow run Get the timings for a workflow run.
-
#v1_workflow_run_get_timings_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1TaskTimingList, Integer, Hash)>
List timings for a workflow run Get the timings for a workflow run.
-
#v1_workflow_run_get_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1WorkflowRunDetails, Integer, Hash)>
List tasks Get a workflow run and its metadata to display on the "detail" page.
-
#v1_workflow_run_list(tenant, since, only_tasks, opts = {}) ⇒ V1TaskSummaryList
List workflow runs Lists workflow runs for a tenant.
-
#v1_workflow_run_list_with_http_info(tenant, since, only_tasks, opts = {}) ⇒ Array<(V1TaskSummaryList, Integer, Hash)>
List workflow runs Lists workflow runs for a tenant.
-
#v1_workflow_run_task_events_list(v1_workflow_run, opts = {}) ⇒ V1TaskEventList
List tasks List all tasks for a workflow run.
-
#v1_workflow_run_task_events_list_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1TaskEventList, Integer, Hash)>
List tasks List all tasks for a workflow run.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WorkflowRunsApi
Returns a new instance of WorkflowRunsApi.
19 20 21 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_durable_task_branch(tenant, v1_branch_durable_task_request, opts = {}) ⇒ V1BranchDurableTaskResponse
Branch durable task Branch a durable task from a specific node, creating a new branch and re-processing its matches.
28 29 30 31 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 28 def v1_durable_task_branch(tenant, v1_branch_durable_task_request, opts = {}) data, _status_code, _headers = v1_durable_task_branch_with_http_info(tenant, v1_branch_durable_task_request, opts) data end |
#v1_durable_task_branch_with_http_info(tenant, v1_branch_durable_task_request, opts = {}) ⇒ Array<(V1BranchDurableTaskResponse, Integer, Hash)>
Branch durable task Branch a durable task from a specific node, creating a new branch and re-processing its matches.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 39 def v1_durable_task_branch_with_http_info(tenant, v1_branch_durable_task_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_durable_task_branch ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunsApi.v1_durable_task_branch" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_durable_task_branch, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_durable_task_branch, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_branch_durable_task_request' is set if @api_client.config.client_side_validation && v1_branch_durable_task_request.nil? fail ArgumentError, "Missing the required parameter 'v1_branch_durable_task_request' when calling WorkflowRunsApi.v1_durable_task_branch" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/durable-tasks/branch'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_branch_durable_task_request) # return_type return_type = opts[:debug_return_type] || 'V1BranchDurableTaskResponse' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_durable_task_branch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_durable_task_branch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_create(tenant, v1_trigger_workflow_run_request, opts = {}) ⇒ V1WorkflowRunDetails
Create workflow run Trigger a new workflow run
110 111 112 113 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 110 def v1_workflow_run_create(tenant, v1_trigger_workflow_run_request, opts = {}) data, _status_code, _headers = v1_workflow_run_create_with_http_info(tenant, v1_trigger_workflow_run_request, opts) data end |
#v1_workflow_run_create_with_http_info(tenant, v1_trigger_workflow_run_request, opts = {}) ⇒ Array<(V1WorkflowRunDetails, Integer, Hash)>
Create workflow run Trigger a new workflow run
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 121 def v1_workflow_run_create_with_http_info(tenant, v1_trigger_workflow_run_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_create ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunsApi.v1_workflow_run_create" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_create, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_create, the character length must be greater than or equal to 36.' end # verify the required parameter 'v1_trigger_workflow_run_request' is set if @api_client.config.client_side_validation && v1_trigger_workflow_run_request.nil? fail ArgumentError, "Missing the required parameter 'v1_trigger_workflow_run_request' when calling WorkflowRunsApi.v1_workflow_run_create" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/workflow-runs/trigger'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_trigger_workflow_run_request) # return_type return_type = opts[:debug_return_type] || 'V1WorkflowRunDetails' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_display_names_list(tenant, external_ids, opts = {}) ⇒ V1WorkflowRunDisplayNameList
List workflow runs Lists displayable names of workflow runs for a tenant
192 193 194 195 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 192 def v1_workflow_run_display_names_list(tenant, external_ids, opts = {}) data, _status_code, _headers = v1_workflow_run_display_names_list_with_http_info(tenant, external_ids, opts) data end |
#v1_workflow_run_display_names_list_with_http_info(tenant, external_ids, opts = {}) ⇒ Array<(V1WorkflowRunDisplayNameList, Integer, Hash)>
List workflow runs Lists displayable names of workflow runs for a tenant
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 203 def v1_workflow_run_display_names_list_with_http_info(tenant, external_ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_display_names_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunsApi.v1_workflow_run_display_names_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_display_names_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_display_names_list, the character length must be greater than or equal to 36.' end # verify the required parameter 'external_ids' is set if @api_client.config.client_side_validation && external_ids.nil? fail ArgumentError, "Missing the required parameter 'external_ids' when calling WorkflowRunsApi.v1_workflow_run_display_names_list" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/workflow-runs/display-names'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'external_ids'] = @api_client.build_collection_param(external_ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1WorkflowRunDisplayNameList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_display_names_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_display_names_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_external_ids_list(tenant, since, opts = {}) ⇒ Array<String>
List workflow run external ids Lists external ids for workflow runs matching filters
275 276 277 278 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 275 def v1_workflow_run_external_ids_list(tenant, since, opts = {}) data, _status_code, _headers = v1_workflow_run_external_ids_list_with_http_info(tenant, since, opts) data end |
#v1_workflow_run_external_ids_list_with_http_info(tenant, since, opts = {}) ⇒ Array<(Array<String>, Integer, Hash)>
List workflow run external ids Lists external ids for workflow runs matching filters
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 291 def v1_workflow_run_external_ids_list_with_http_info(tenant, since, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_external_ids_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunsApi.v1_workflow_run_external_ids_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_external_ids_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_external_ids_list, the character length must be greater than or equal to 36.' end # verify the required parameter 'since' is set if @api_client.config.client_side_validation && since.nil? fail ArgumentError, "Missing the required parameter 'since' when calling WorkflowRunsApi.v1_workflow_run_external_ids_list" end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/workflow-runs/external-ids'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'since'] = since query_params[:'statuses'] = @api_client.build_collection_param(opts[:'statuses'], :multi) if !opts[:'statuses'].nil? query_params[:'until'] = opts[:'_until'] if !opts[:'_until'].nil? query_params[:'additional_metadata'] = @api_client.build_collection_param(opts[:'additional_metadata'], :multi) if !opts[:'additional_metadata'].nil? query_params[:'workflow_ids'] = @api_client.build_collection_param(opts[:'workflow_ids'], :multi) if !opts[:'workflow_ids'].nil? query_params[:'running_filter'] = opts[:'running_filter'] if !opts[:'running_filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<String>' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_external_ids_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_external_ids_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_get(v1_workflow_run, opts = {}) ⇒ V1WorkflowRunDetails
List tasks Get a workflow run and its metadata to display on the "detail" page
362 363 364 365 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 362 def v1_workflow_run_get(v1_workflow_run, opts = {}) data, _status_code, _headers = v1_workflow_run_get_with_http_info(v1_workflow_run, opts) data end |
#v1_workflow_run_get_status(v1_workflow_run, opts = {}) ⇒ V1TaskStatus
Get workflow run status Get the status of a workflow run.
433 434 435 436 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 433 def v1_workflow_run_get_status(v1_workflow_run, opts = {}) data, _status_code, _headers = v1_workflow_run_get_status_with_http_info(v1_workflow_run, opts) data end |
#v1_workflow_run_get_status_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1TaskStatus, Integer, Hash)>
Get workflow run status Get the status of a workflow run.
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 443 def v1_workflow_run_get_status_with_http_info(v1_workflow_run, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_get_status ...' end # verify the required parameter 'v1_workflow_run' is set if @api_client.config.client_side_validation && v1_workflow_run.nil? fail ArgumentError, "Missing the required parameter 'v1_workflow_run' when calling WorkflowRunsApi.v1_workflow_run_get_status" end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_get_status, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_get_status, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/workflow-runs/{v1-workflow-run}/status'.sub('{' + 'v1-workflow-run' + '}', CGI.escape(v1_workflow_run.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1TaskStatus' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_get_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_get_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_get_timings(v1_workflow_run, opts = {}) ⇒ V1TaskTimingList
List timings for a workflow run Get the timings for a workflow run
505 506 507 508 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 505 def v1_workflow_run_get_timings(v1_workflow_run, opts = {}) data, _status_code, _headers = v1_workflow_run_get_timings_with_http_info(v1_workflow_run, opts) data end |
#v1_workflow_run_get_timings_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1TaskTimingList, Integer, Hash)>
List timings for a workflow run Get the timings for a workflow run
516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 516 def v1_workflow_run_get_timings_with_http_info(v1_workflow_run, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_get_timings ...' end # verify the required parameter 'v1_workflow_run' is set if @api_client.config.client_side_validation && v1_workflow_run.nil? fail ArgumentError, "Missing the required parameter 'v1_workflow_run' when calling WorkflowRunsApi.v1_workflow_run_get_timings" end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_get_timings, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_get_timings, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/workflow-runs/{v1-workflow-run}/task-timings'.sub('{' + 'v1-workflow-run' + '}', CGI.escape(v1_workflow_run.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'depth'] = opts[:'depth'] if !opts[:'depth'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1TaskTimingList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_get_timings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_get_timings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_get_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1WorkflowRunDetails, Integer, Hash)>
List tasks Get a workflow run and its metadata to display on the "detail" page
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 372 def v1_workflow_run_get_with_http_info(v1_workflow_run, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_get ...' end # verify the required parameter 'v1_workflow_run' is set if @api_client.config.client_side_validation && v1_workflow_run.nil? fail ArgumentError, "Missing the required parameter 'v1_workflow_run' when calling WorkflowRunsApi.v1_workflow_run_get" end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_get, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_get, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/workflow-runs/{v1-workflow-run}'.sub('{' + 'v1-workflow-run' + '}', CGI.escape(v1_workflow_run.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1WorkflowRunDetails' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_list(tenant, since, only_tasks, opts = {}) ⇒ V1TaskSummaryList
List workflow runs Lists workflow runs for a tenant.
593 594 595 596 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 593 def v1_workflow_run_list(tenant, since, only_tasks, opts = {}) data, _status_code, _headers = v1_workflow_run_list_with_http_info(tenant, since, only_tasks, opts) data end |
#v1_workflow_run_list_with_http_info(tenant, since, only_tasks, opts = {}) ⇒ Array<(V1TaskSummaryList, Integer, Hash)>
List workflow runs Lists workflow runs for a tenant.
618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 618 def v1_workflow_run_list_with_http_info(tenant, since, only_tasks, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_list ...' end # verify the required parameter 'tenant' is set if @api_client.config.client_side_validation && tenant.nil? fail ArgumentError, "Missing the required parameter 'tenant' when calling WorkflowRunsApi.v1_workflow_run_list" end if @api_client.config.client_side_validation && tenant.to_s.length > 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && tenant.to_s.length < 36 fail ArgumentError, 'invalid value for "tenant" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be greater than or equal to 36.' end # verify the required parameter 'since' is set if @api_client.config.client_side_validation && since.nil? fail ArgumentError, "Missing the required parameter 'since' when calling WorkflowRunsApi.v1_workflow_run_list" end # verify the required parameter 'only_tasks' is set if @api_client.config.client_side_validation && only_tasks.nil? fail ArgumentError, "Missing the required parameter 'only_tasks' when calling WorkflowRunsApi.v1_workflow_run_list" end if @api_client.config.client_side_validation && !opts[:'worker_id'].nil? && opts[:'worker_id'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"worker_id"]" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'worker_id'].nil? && opts[:'worker_id'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"worker_id"]" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be greater than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'parent_task_external_id'].nil? && opts[:'parent_task_external_id'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"parent_task_external_id"]" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'parent_task_external_id'].nil? && opts[:'parent_task_external_id'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"parent_task_external_id"]" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be greater than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'triggering_event_external_id'].nil? && opts[:'triggering_event_external_id'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"triggering_event_external_id"]" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'triggering_event_external_id'].nil? && opts[:'triggering_event_external_id'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"triggering_event_external_id"]" when calling WorkflowRunsApi.v1_workflow_run_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/tenants/{tenant}/workflow-runs'.sub('{' + 'tenant' + '}', CGI.escape(tenant.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'since'] = since query_params[:'only_tasks'] = only_tasks query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'statuses'] = @api_client.build_collection_param(opts[:'statuses'], :multi) if !opts[:'statuses'].nil? query_params[:'until'] = opts[:'_until'] if !opts[:'_until'].nil? query_params[:'additional_metadata'] = @api_client.build_collection_param(opts[:'additional_metadata'], :multi) if !opts[:'additional_metadata'].nil? query_params[:'additional_metadata_operator'] = opts[:'additional_metadata_operator'] if !opts[:'additional_metadata_operator'].nil? query_params[:'workflow_ids'] = @api_client.build_collection_param(opts[:'workflow_ids'], :multi) if !opts[:'workflow_ids'].nil? query_params[:'worker_id'] = opts[:'worker_id'] if !opts[:'worker_id'].nil? query_params[:'parent_task_external_id'] = opts[:'parent_task_external_id'] if !opts[:'parent_task_external_id'].nil? query_params[:'triggering_event_external_id'] = opts[:'triggering_event_external_id'] if !opts[:'triggering_event_external_id'].nil? query_params[:'include_payloads'] = opts[:'include_payloads'] if !opts[:'include_payloads'].nil? query_params[:'running_filter'] = opts[:'running_filter'] if !opts[:'running_filter'].nil? query_params[:'idempotency_keys'] = @api_client.build_collection_param(opts[:'idempotency_keys'], :multi) if !opts[:'idempotency_keys'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1TaskSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_workflow_run_task_events_list(v1_workflow_run, opts = {}) ⇒ V1TaskEventList
List tasks List all tasks for a workflow run
728 729 730 731 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 728 def v1_workflow_run_task_events_list(v1_workflow_run, opts = {}) data, _status_code, _headers = v1_workflow_run_task_events_list_with_http_info(v1_workflow_run, opts) data end |
#v1_workflow_run_task_events_list_with_http_info(v1_workflow_run, opts = {}) ⇒ Array<(V1TaskEventList, Integer, Hash)>
List tasks List all tasks for a workflow run
740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/hatchet/clients/rest/lib/hatchet-sdk-rest/api/workflow_runs_api.rb', line 740 def v1_workflow_run_task_events_list_with_http_info(v1_workflow_run, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowRunsApi.v1_workflow_run_task_events_list ...' end # verify the required parameter 'v1_workflow_run' is set if @api_client.config.client_side_validation && v1_workflow_run.nil? fail ArgumentError, "Missing the required parameter 'v1_workflow_run' when calling WorkflowRunsApi.v1_workflow_run_task_events_list" end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length > 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_task_events_list, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && v1_workflow_run.to_s.length < 36 fail ArgumentError, 'invalid value for "v1_workflow_run" when calling WorkflowRunsApi.v1_workflow_run_task_events_list, the character length must be greater than or equal to 36.' end # resource path local_var_path = '/api/v1/stable/workflow-runs/{v1-workflow-run}/task-events'.sub('{' + 'v1-workflow-run' + '}', CGI.escape(v1_workflow_run.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1TaskEventList' # auth_names auth_names = opts[:debug_auth_names] || ['cookieAuth', 'bearerAuth'] = opts.merge( :operation => :"WorkflowRunsApi.v1_workflow_run_task_events_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowRunsApi#v1_workflow_run_task_events_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |